=> Bootstrap dependency digest>=20010302: found digest-20121220
=> Bootstrap dependency fetch-[0-9]*: found fetch-1.8nb1
WARNING: [license.mk] Every package should define a LICENSE.
=> Checksum SHA1 OK for seamonkey-2.18b4.source.tar.bz2
=> Checksum RMD160 OK for seamonkey-2.18b4.source.tar.bz2
===> Installing dependencies for seamonkey-2.18beta4
==========================================================================
The supported build options for seamonkey are:

	debug gnome mozilla-enigmail mozilla-jemalloc
	mozilla-lightning

The currently selected options are:

	mozilla-jemalloc

You can select which build options to use by setting PKG_DEFAULT_OPTIONS
or the following variable.  Its current value is shown:

	PKG_OPTIONS.seamonkey (not defined)

==========================================================================
==========================================================================
The following variables will affect the build process of this package,
seamonkey-2.18beta4.  Their current value is shown below:

        * PYTHON_VERSION_DEFAULT = 27
        * SSLBASE (defined)
        * SSLCERTS = /usr/pkg/etc/openssl/certs
        * SSLDIR = /usr/pkg/etc/openssl
        * SSLKEYS = /usr/pkg/etc/openssl/private

Based on these variables, the following variables have been set:

        * PYPACKAGE = python27

You may want to abort the process now with CTRL-C and change their value
before continuing.  Be sure to run `/usr/pkg/bin/bmake clean' after
the changes.
==========================================================================
=> Tool dependency autoconf213>=2.13: found autoconf213-2.13nb2
=> Tool dependency nbpatch-[0-9]*: found nbpatch-20100124
=> Tool dependency perl>=5.0: found perl-5.16.3
=> Tool dependency pkg-config>=0.25: found pkg-config-0.28
=> Tool dependency unzip-[0-9]*: found unzip-6.0nb1
=> Tool dependency zip-[0-9]*: found zip-3.0nb2
=> Tool dependency zip-[0-9]*: found zip-3.0nb2
=> Tool dependency zip-[0-9]*: found zip-3.0nb2
=> Tool dependency zip-[0-9]*: found zip-3.0nb2
=> Tool dependency checkperms>=1.1: found checkperms-1.11
=> Build dependency yasm>=1.1.0: found yasm-1.2.0
=> Build dependency py27-sqlite2-[0-9]*: found py27-sqlite2-2.6.3nb5
=> Build dependency python27>=2.7.1nb2: found python27-2.7.5
=> Build dependency dri2proto>=2.0: found dri2proto-2.8
=> Build dependency glproto>=1.4.6: found glproto-1.4.16
=> Build dependency damageproto>=1.1.0: found damageproto-1.2.1
=> Build dependency xproto>=7.0.9: found xproto-7.0.24nb1
=> Build dependency fixesproto>=3.0.0: found fixesproto-5.0
=> Build dependency xextproto>=7.0: found xextproto-7.2.1
=> Build dependency inputproto>=1.4: found inputproto-2.3
=> Build dependency kbproto>=1.0.2: found kbproto-1.0.6
=> Build dependency xcb-proto>=1.4: found xcb-proto-1.8
=> Build dependency xf86vidmodeproto>=2.3: found xf86vidmodeproto-2.3.1
=> Build dependency xf86driproto>=2.0.3: found xf86driproto-2.1.1
=> Build dependency renderproto>=0.9.3nb1: found renderproto-0.11.1
=> Build dependency randrproto>=1.2.0: found randrproto-1.4.0
=> Build dependency xineramaproto>=1.1.1: found xineramaproto-1.2.1
=> Build dependency compositeproto>=0.3.1: found compositeproto-0.4.2
=> Full dependency alsa-lib>=1.0.18: found alsa-lib-1.0.22
=> Full dependency bzip2>=1.0.3: found bzip2-1.0.6
=> Full dependency sqlite3>=3.7.16.2nb1: found sqlite3-3.7.17
=> Full dependency libevent>=2.0.10: found libevent-2.0.21nb2
=> Full dependency libffi>=3.0.11: found libffi-3.0.13
=> Full dependency nspr>=4.9.4: found nspr-4.9.6
=> Full dependency nss>=3.14.1: found nss-3.14.3nb1
=> Full dependency zlib>=1.2.3: found zlib-1.2.8
=> Full dependency MesaLib>=7.11.2: found MesaLib-7.11.2nb1
=> Full dependency cairo>=1.12.14nb1: found cairo-1.12.14nb1
=> Full dependency libvpx>=1.0.0: found libvpx-1.1.0nb2
=> Full dependency libIDL>=0.8.14nb4: found libIDL-0.8.14nb4
=> Full dependency hunspell>=1.3.2: found hunspell-1.3.2nb1
=> Full dependency gtk2+>=2.24.15nb1: found gtk2+-2.24.17
=> Full dependency libXt>=1.0.0: found libXt-1.1.3
===> Overriding tools for seamonkey-2.18beta4
===> Extracting for seamonkey-2.18beta4
===> Patching for seamonkey-2.18beta4
=> Applying pkgsrc patches for seamonkey-2.18beta4
=> Verifying /usr/pkgsrc/www/seamonkey/patches/patch-aa
=> Applying pkgsrc patch /usr/pkgsrc/www/seamonkey/patches/patch-aa
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-aa,v 1.15 2013/05/23 13:25:30 ryoon Exp $
|
|--- mozilla/configure.in.orig	2013-05-03 03:07:49.000000000 +0000
|+++ mozilla/configure.in
--------------------------
Patching file mozilla/configure.in using Plan A...
Hunk #1 succeeded at 1404.
Hunk #2 succeeded at 2077.
Hunk #3 succeeded at 2862.
Hunk #4 succeeded at 2871.
Hunk #5 succeeded at 3033.
Hunk #6 succeeded at 3337.
Hunk #7 succeeded at 4010.
Hunk #8 succeeded at 4045.
Hunk #9 succeeded at 5237.
Hunk #10 succeeded at 5292.
Hunk #11 succeeded at 5331.
Hunk #12 succeeded at 5736.
Hunk #13 succeeded at 8343.
Hunk #14 succeeded at 9023.
done
=> Verifying /usr/pkgsrc/www/seamonkey/patches/patch-aa-toplevel
=> Applying pkgsrc patch /usr/pkgsrc/www/seamonkey/patches/patch-aa-toplevel
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-aa-toplevel,v 1.11 2013/03/22 21:02:46 ryoon Exp $
|
|--- configure.in.orig	2013-02-18 03:58:37.000000000 +0000
|+++ configure.in
--------------------------
Patching file configure.in using Plan A...
Hunk #1 succeeded at 1590 (offset 17 lines).
Hunk #2 succeeded at 1598 (offset 17 lines).
Hunk #3 succeeded at 2519 (offset 5 lines).
Hunk #4 succeeded at 2844 (offset 17 lines).
done
=> Verifying /usr/pkgsrc/www/seamonkey/patches/patch-ak
=> Applying pkgsrc patch /usr/pkgsrc/www/seamonkey/patches/patch-ak
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-ak,v 1.11 2013/01/07 21:55:30 ryoon Exp $
|
|--- mozilla/js/src/ctypes/libffi/configure.orig	2012-11-18 10:19:38.000000000 +0000
|+++ mozilla/js/src/ctypes/libffi/configure
--------------------------
Patching file mozilla/js/src/ctypes/libffi/configure using Plan A...
Hunk #1 succeeded at 11278.
done
=> Verifying /usr/pkgsrc/www/seamonkey/patches/patch-al
=> Applying pkgsrc patch /usr/pkgsrc/www/seamonkey/patches/patch-al
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-al,v 1.11 2013/01/07 21:55:30 ryoon Exp $
|
|--- mozilla/storage/src/mozStorageConnection.cpp.orig	2012-11-18 10:19:51.000000000 +0000
|+++ mozilla/storage/src/mozStorageConnection.cpp
--------------------------
Patching file mozilla/storage/src/mozStorageConnection.cpp using Plan A...
Hunk #1 succeeded at 635 (offset 64 lines).
done
=> Verifying /usr/pkgsrc/www/seamonkey/patches/patch-am
=> Applying pkgsrc patch /usr/pkgsrc/www/seamonkey/patches/patch-am
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-am,v 1.7 2013/01/07 21:55:30 ryoon Exp $
|
|SHA1_Update conflicts with openssl which may be dynamically loaded
|at runtime via libcups or libgssapi so causing a crash due to using
|the wrong binding.  So rename here to avoid conflict.
|
|--- mozilla/security/nss/lib/freebl/blapi.h.orig	2012-11-18 10:19:50.000000000 +0000
|+++ mozilla/security/nss/lib/freebl/blapi.h
--------------------------
Patching file mozilla/security/nss/lib/freebl/blapi.h using Plan A...
Hunk #1 succeeded at 1022 (offset -21 lines).
done
=> Verifying /usr/pkgsrc/www/seamonkey/patches/patch-an
=> Applying pkgsrc patch /usr/pkgsrc/www/seamonkey/patches/patch-an
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-an,v 1.9 2013/01/07 21:55:30 ryoon Exp $
|
|SHA1_Update conflicts with openssl which may be dynamically loaded
|at runtime via libcups or libgssapi so causing a crash due to using
|the wrong binding.  So rename here to avoid conflict.
|
|--- mozilla/security/nss/lib/freebl/sha-fast-amd64-sun.s.orig	2012-11-18 10:19:50.000000000 +0000
|+++ mozilla/security/nss/lib/freebl/sha-fast-amd64-sun.s
--------------------------
Patching file mozilla/security/nss/lib/freebl/sha-fast-amd64-sun.s using Plan A...
Hunk #1 succeeded at 1680 (offset -32 lines).
Hunk #2 succeeded at 1768 (offset -32 lines).
Hunk #3 succeeded at 1870 (offset -32 lines).
Hunk #4 succeeded at 1986 (offset -32 lines).
done
=> Verifying /usr/pkgsrc/www/seamonkey/patches/patch-ao
=> Applying pkgsrc patch /usr/pkgsrc/www/seamonkey/patches/patch-ao
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-ao,v 1.12 2013/04/07 20:23:49 ryoon Exp $
|
|--- mozilla/toolkit/mozapps/installer/packager.mk.orig	2013-04-01 03:31:14.000000000 +0000
|+++ mozilla/toolkit/mozapps/installer/packager.mk
--------------------------
Patching file mozilla/toolkit/mozapps/installer/packager.mk using Plan A...
No such line 910 in input file, ignoring
Hunk #1 succeeded at 652 (offset -259 lines).
done
=> Verifying /usr/pkgsrc/www/seamonkey/patches/patch-as
=> Applying pkgsrc patch /usr/pkgsrc/www/seamonkey/patches/patch-as
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-as,v 1.12 2013/05/23 13:25:30 ryoon Exp $
|
|* Fix _res is not supported for multi-threaded programs. error.
|* Treat DragonFly like FreeBSD.
|
|--- mozilla/js/src/configure.in.orig	2013-05-03 03:07:57.000000000 +0000
|+++ mozilla/js/src/configure.in
--------------------------
Patching file mozilla/js/src/configure.in using Plan A...
Hunk #1 succeeded at 2399.
Hunk #2 succeeded at 2408.
Hunk #3 succeeded at 2629.
Hunk #4 succeeded at 2712.
Hunk #5 succeeded at 3490.
done
=> Verifying /usr/pkgsrc/www/seamonkey/patches/patch-au
=> Applying pkgsrc patch /usr/pkgsrc/www/seamonkey/patches/patch-au
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-au,v 1.10 2013/05/23 13:25:30 ryoon Exp $
|
|- Fix device name on NetBSD
|- SOUND_VERSION just isn't a reliable way to detect features supported by
|  particular OSS implementation.
|
|--- mozilla/media/libsydneyaudio/src/sydney_audio_oss.c.orig	2013-05-03 03:08:05.000000000 +0000
|+++ mozilla/media/libsydneyaudio/src/sydney_audio_oss.c
--------------------------
Patching file mozilla/media/libsydneyaudio/src/sydney_audio_oss.c using Plan A...
Hunk #1 succeeded at 23.
Hunk #2 succeeded at 173.
Hunk #3 succeeded at 451.
done
=> Verifying /usr/pkgsrc/www/seamonkey/patches/patch-az
=> Applying pkgsrc patch /usr/pkgsrc/www/seamonkey/patches/patch-az
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-az,v 1.7 2013/01/07 21:55:30 ryoon Exp $
|
|--- mozilla/nsprpub/pr/src/pthreads/ptthread.c.orig	2012-11-18 10:19:49.000000000 +0000
|+++ mozilla/nsprpub/pr/src/pthreads/ptthread.c
--------------------------
Patching file mozilla/nsprpub/pr/src/pthreads/ptthread.c using Plan A...
Hunk #1 succeeded at 1099 (offset 58 lines).
done
=> Verifying /usr/pkgsrc/www/seamonkey/patches/patch-ba
=> Applying pkgsrc patch /usr/pkgsrc/www/seamonkey/patches/patch-ba
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-ba,v 1.11 2013/01/07 21:55:30 ryoon Exp $
|
|pthread_t may be 64-bit, avoid casting it.
|
|--- mozilla/nsprpub/pr/include/private/pprthred.h.orig	2012-11-18 10:19:49.000000000 +0000
|+++ mozilla/nsprpub/pr/include/private/pprthred.h
--------------------------
Patching file mozilla/nsprpub/pr/include/private/pprthred.h using Plan A...
Hunk #1 succeeded at 19.
Hunk #2 succeeded at 61.
done
=> Verifying /usr/pkgsrc/www/seamonkey/patches/patch-bd
=> Applying pkgsrc patch /usr/pkgsrc/www/seamonkey/patches/patch-bd
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-bd,v 1.8 2013/01/07 21:55:30 ryoon Exp $
|
|--- mozilla/js/src/ctypes/CTypes.cpp.orig	2012-11-18 10:19:38.000000000 +0000
|+++ mozilla/js/src/ctypes/CTypes.cpp
--------------------------
Patching file mozilla/js/src/ctypes/CTypes.cpp using Plan A...
Hunk #1 succeeded at 5.
done
=> Verifying /usr/pkgsrc/www/seamonkey/patches/patch-bf
=> Applying pkgsrc patch /usr/pkgsrc/www/seamonkey/patches/patch-bf
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-bf,v 1.12 2013/04/07 20:23:49 ryoon Exp $
|
|--- mozilla/js/src/jsnativestack.cpp.orig	2013-04-01 03:30:59.000000000 +0000
|+++ mozilla/js/src/jsnativestack.cpp
--------------------------
Patching file mozilla/js/src/jsnativestack.cpp using Plan A...
Hunk #1 succeeded at 19.
Hunk #2 succeeded at 112.
done
=> Verifying /usr/pkgsrc/www/seamonkey/patches/patch-bg
=> Applying pkgsrc patch /usr/pkgsrc/www/seamonkey/patches/patch-bg
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-bg,v 1.7 2013/01/07 21:55:30 ryoon Exp $
|
|--- mozilla/storage/src/SQLiteMutex.h.orig	2012-11-18 10:19:51.000000000 +0000
|+++ mozilla/storage/src/SQLiteMutex.h
--------------------------
Patching file mozilla/storage/src/SQLiteMutex.h using Plan A...
Hunk #1 succeeded at 108.
done
=> Verifying /usr/pkgsrc/www/seamonkey/patches/patch-bi
=> Applying pkgsrc patch /usr/pkgsrc/www/seamonkey/patches/patch-bi
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-bi,v 1.7 2013/01/07 21:55:30 ryoon Exp $
|
|--- mozilla/gfx/angle/src/compiler/osinclude.h.orig	2012-11-18 10:19:36.000000000 +0000
|+++ mozilla/gfx/angle/src/compiler/osinclude.h
--------------------------
Patching file mozilla/gfx/angle/src/compiler/osinclude.h using Plan A...
Hunk #1 succeeded at 16.
done
=> Verifying /usr/pkgsrc/www/seamonkey/patches/patch-config_baseconfig.mk
=> Applying pkgsrc patch /usr/pkgsrc/www/seamonkey/patches/patch-config_baseconfig.mk
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-config_baseconfig.mk,v 1.2 2013/01/07 21:55:30 ryoon Exp $
|
|--- config/baseconfig.mk.orig	2012-11-18 10:14:23.000000000 +0000
|+++ config/baseconfig.mk
--------------------------
Patching file config/baseconfig.mk using Plan A...
Hunk #1 succeeded at 1.
done
=> Verifying /usr/pkgsrc/www/seamonkey/patches/patch-ldap_sdks_c-sdk_build.mk
=> Applying pkgsrc patch /usr/pkgsrc/www/seamonkey/patches/patch-ldap_sdks_c-sdk_build.mk
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-ldap_sdks_c-sdk_build.mk,v 1.4 2013/01/07 21:55:30 ryoon Exp $
|
|--- ldap/sdks/c-sdk/build.mk.orig	2012-11-18 10:20:06.000000000 +0000
|+++ ldap/sdks/c-sdk/build.mk
--------------------------
Patching file ldap/sdks/c-sdk/build.mk using Plan A...
Hunk #1 succeeded at 488.
Hunk #2 succeeded at 517.
done
=> Verifying /usr/pkgsrc/www/seamonkey/patches/patch-ldap_sdks_c-sdk_ldap_include_portable.h
=> Applying pkgsrc patch /usr/pkgsrc/www/seamonkey/patches/patch-ldap_sdks_c-sdk_ldap_include_portable.h
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-ldap_sdks_c-sdk_ldap_include_portable.h,v 1.1 2013/05/23 13:25:30 ryoon Exp $
|
|--- ldap/sdks/c-sdk/ldap/include/portable.h.orig	2012-11-18 10:20:06.000000000 +0000
|+++ ldap/sdks/c-sdk/ldap/include/portable.h
--------------------------
Patching file ldap/sdks/c-sdk/ldap/include/portable.h using Plan A...
Hunk #1 succeeded at 122.
done
=> Verifying /usr/pkgsrc/www/seamonkey/patches/patch-mail_app_Makefile.in
=> Applying pkgsrc patch /usr/pkgsrc/www/seamonkey/patches/patch-mail_app_Makefile.in
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-mail_app_Makefile.in,v 1.6 2013/01/07 21:55:30 ryoon Exp $
|
|--- mail/app/Makefile.in.orig	2012-11-18 10:14:23.000000000 +0000
|+++ mail/app/Makefile.in
--------------------------
Patching file mail/app/Makefile.in using Plan A...
Hunk #1 succeeded at 63.
done
=> Verifying /usr/pkgsrc/www/seamonkey/patches/patch-mb
=> Applying pkgsrc patch /usr/pkgsrc/www/seamonkey/patches/patch-mb
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-mb,v 1.10 2013/05/23 13:25:30 ryoon Exp $
|
|--- mozilla/xpcom/reflect/xptcall/src/md/unix/Makefile.in.orig	2013-05-03 03:08:15.000000000 +0000
|+++ mozilla/xpcom/reflect/xptcall/src/md/unix/Makefile.in
--------------------------
Patching file mozilla/xpcom/reflect/xptcall/src/md/unix/Makefile.in using Plan A...
Hunk #1 succeeded at 50.
Hunk #2 succeeded at 59.
Hunk #3 succeeded at 158.
Hunk #4 succeeded at 215.
Hunk #5 succeeded at 287.
Hunk #6 succeeded at 346.
done
=> Verifying /usr/pkgsrc/www/seamonkey/patches/patch-md
=> Applying pkgsrc patch /usr/pkgsrc/www/seamonkey/patches/patch-md
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-md,v 1.7 2013/01/07 21:55:30 ryoon Exp $
|
|???. from www/firefox/patch-ax.
|
|--- mozilla/security/coreconf/SunOS5.mk.orig	2012-11-18 10:19:50.000000000 +0000
|+++ mozilla/security/coreconf/SunOS5.mk
--------------------------
Patching file mozilla/security/coreconf/SunOS5.mk using Plan A...
No such line 146 in input file, ignoring
Hunk #1 succeeded at 113 (offset -34 lines).
done
=> Verifying /usr/pkgsrc/www/seamonkey/patches/patch-me
=> Applying pkgsrc patch /usr/pkgsrc/www/seamonkey/patches/patch-me
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-me,v 1.11 2013/05/23 13:25:30 ryoon Exp $
|
|Add DragonFly support.
|
|--- mozilla/security/nss/lib/freebl/Makefile.orig	2012-11-18 10:19:50.000000000 +0000
|+++ mozilla/security/nss/lib/freebl/Makefile
--------------------------
Patching file mozilla/security/nss/lib/freebl/Makefile using Plan A...
Hunk #1 succeeded at 257 (offset -22 lines).
done
=> Verifying /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_build_autoconf_nss.m4
=> Applying pkgsrc patch /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_build_autoconf_nss.m4
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-mozilla_build_autoconf_nss.m4,v 1.6 2013/01/07 21:55:30 ryoon Exp $
|
|--- mozilla/build/autoconf/nss.m4.orig	2012-11-18 10:19:31.000000000 +0000
|+++ mozilla/build/autoconf/nss.m4
--------------------------
Patching file mozilla/build/autoconf/nss.m4 using Plan A...
Hunk #1 succeeded at 22.
Hunk #2 succeeded at 41.
done
=> Verifying /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_config_baseconfig.mk
=> Applying pkgsrc patch /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_config_baseconfig.mk
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-mozilla_config_baseconfig.mk,v 1.2 2013/01/07 21:55:30 ryoon Exp $
|
|--- mozilla/config/baseconfig.mk.orig	2012-11-18 10:19:31.000000000 +0000
|+++ mozilla/config/baseconfig.mk
--------------------------
Patching file mozilla/config/baseconfig.mk using Plan A...
Hunk #1 succeeded at 1.
done
=> Verifying /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_config_stl__wrappers_ios
=> Applying pkgsrc patch /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_config_stl__wrappers_ios
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-mozilla_config_stl__wrappers_ios,v 1.1 2013/05/14 19:08:42 joerg Exp $
|
|--- mozilla/config/stl_wrappers/ios.orig	2013-05-13 18:23:07.000000000 +0000
|+++ mozilla/config/stl_wrappers/ios
--------------------------
(Creating file mozilla/config/stl_wrappers/ios...)
Patching file mozilla/config/stl_wrappers/ios using Plan A...
Empty context always matches.
Hunk #1 succeeded at 1.
done
=> Verifying /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_config_stl__wrappers_ostream
=> Applying pkgsrc patch /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_config_stl__wrappers_ostream
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-mozilla_config_stl__wrappers_ostream,v 1.1 2013/05/14 19:08:42 joerg Exp $
|
|--- mozilla/config/stl_wrappers/ostream.orig	2013-05-13 18:22:40.000000000 +0000
|+++ mozilla/config/stl_wrappers/ostream
--------------------------
(Creating file mozilla/config/stl_wrappers/ostream...)
Patching file mozilla/config/stl_wrappers/ostream using Plan A...
Empty context always matches.
Hunk #1 succeeded at 1.
done
=> Verifying /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_config_system-headers
=> Applying pkgsrc patch /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_config_system-headers
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-mozilla_config_system-headers,v 1.6 2013/05/23 13:25:30 ryoon Exp $
|
|--- mozilla/config/system-headers.orig	2013-05-03 03:07:49.000000000 +0000
|+++ mozilla/config/system-headers
--------------------------
Patching file mozilla/config/system-headers using Plan A...
Hunk #1 succeeded at 1126.
done
=> Verifying /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_config_system__wrappers_unwind.h
=> Applying pkgsrc patch /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_config_system__wrappers_unwind.h
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-mozilla_config_system__wrappers_unwind.h,v 1.1 2013/05/14 19:08:42 joerg Exp $
|
|--- mozilla/config/system_wrappers/unwind.h.orig	2013-05-13 19:56:18.000000000 +0000
|+++ mozilla/config/system_wrappers/unwind.h
--------------------------
(Creating file mozilla/config/system_wrappers/unwind.h...)
Patching file mozilla/config/system_wrappers/unwind.h using Plan A...
Empty context always matches.
Hunk #1 succeeded at 1.
done
=> Verifying /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_content_media_AudioStream.cpp
=> Applying pkgsrc patch /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_content_media_AudioStream.cpp
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-mozilla_content_media_AudioStream.cpp,v 1.1 2013/05/23 13:25:30 ryoon Exp $
|
|--- mozilla/content/media/AudioStream.cpp.orig	2013-05-03 03:07:50.000000000 +0000
|+++ mozilla/content/media/AudioStream.cpp
--------------------------
Patching file mozilla/content/media/AudioStream.cpp using Plan A...
Hunk #1 succeeded at 314.
done
=> Verifying /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_extensions_auth_nsAuthGSSAPI.cpp
=> Applying pkgsrc patch /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_extensions_auth_nsAuthGSSAPI.cpp
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-mozilla_extensions_auth_nsAuthGSSAPI.cpp,v 1.1 2013/05/23 13:25:30 ryoon Exp $
|
|--- mozilla/extensions/auth/nsAuthGSSAPI.cpp.orig	2013-05-03 03:07:54.000000000 +0000
|+++ mozilla/extensions/auth/nsAuthGSSAPI.cpp
--------------------------
Patching file mozilla/extensions/auth/nsAuthGSSAPI.cpp using Plan A...
Hunk #1 succeeded at 39.
done
=> Verifying /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_gfx_skia_Makefile.in
=> Applying pkgsrc patch /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_gfx_skia_Makefile.in
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-mozilla_gfx_skia_Makefile.in,v 1.1 2013/01/20 08:33:14 ryoon Exp $
|
|--- mozilla/gfx/skia/Makefile.in.orig	2013-01-06 06:26:15.000000000 +0000
|+++ mozilla/gfx/skia/Makefile.in
--------------------------
Patching file mozilla/gfx/skia/Makefile.in using Plan A...
Hunk #1 succeeded at 356 (offset 1 line).
done
=> Verifying /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_gfx_skia_src_sfnt_SkOTTable__head.h
=> Applying pkgsrc patch /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_gfx_skia_src_sfnt_SkOTTable__head.h
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-mozilla_gfx_skia_src_sfnt_SkOTTable__head.h,v 1.1 2013/01/20 08:33:14 ryoon Exp $
|
|--- mozilla/gfx/skia/src/sfnt/SkOTTable_head.h.orig	2013-01-06 06:26:15.000000000 +0000
|+++ mozilla/gfx/skia/src/sfnt/SkOTTable_head.h
--------------------------
Patching file mozilla/gfx/skia/src/sfnt/SkOTTable_head.h using Plan A...
Hunk #1 succeeded at 12.
Hunk #2 succeeded at 140.
done
=> Verifying /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_gfx_skia_src_sfnt_SkOTTable__name.h
=> Applying pkgsrc patch /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_gfx_skia_src_sfnt_SkOTTable__name.h
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-mozilla_gfx_skia_src_sfnt_SkOTTable__name.h,v 1.1 2013/01/20 08:33:14 ryoon Exp $
|
|--- mozilla/gfx/skia/src/sfnt/SkOTTable_name.h.orig	2013-01-06 06:26:15.000000000 +0000
|+++ mozilla/gfx/skia/src/sfnt/SkOTTable_name.h
--------------------------
Patching file mozilla/gfx/skia/src/sfnt/SkOTTable_name.h using Plan A...
Hunk #1 succeeded at 12.
Hunk #2 succeeded at 499.
done
=> Verifying /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_gfx_skia_src_sfnt_SkSFNTHeader.h
=> Applying pkgsrc patch /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_gfx_skia_src_sfnt_SkSFNTHeader.h
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-mozilla_gfx_skia_src_sfnt_SkSFNTHeader.h,v 1.1 2013/01/20 08:33:14 ryoon Exp $
|
|--- mozilla/gfx/skia/src/sfnt/SkSFNTHeader.h.orig	2013-01-06 06:26:15.000000000 +0000
|+++ mozilla/gfx/skia/src/sfnt/SkSFNTHeader.h
--------------------------
Patching file mozilla/gfx/skia/src/sfnt/SkSFNTHeader.h using Plan A...
Hunk #1 succeeded at 15.
Hunk #2 succeeded at 61.
done
=> Verifying /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_gfx_thebes_gfxPlatform.cpp
=> Applying pkgsrc patch /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_gfx_thebes_gfxPlatform.cpp
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-mozilla_gfx_thebes_gfxPlatform.cpp,v 1.5 2013/01/20 08:33:14 ryoon Exp $
|
|--- mozilla/gfx/thebes/gfxPlatform.cpp.orig	2013-01-06 06:26:16.000000000 +0000
|+++ mozilla/gfx/thebes/gfxPlatform.cpp
--------------------------
Patching file mozilla/gfx/thebes/gfxPlatform.cpp using Plan A...
Hunk #1 succeeded at 533 (offset 26 lines).
Hunk #2 succeeded at 650 (offset 26 lines).
done
=> Verifying /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_image_decoders_nsJPEGDecoder.cpp
=> Applying pkgsrc patch /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_image_decoders_nsJPEGDecoder.cpp
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-mozilla_image_decoders_nsJPEGDecoder.cpp,v 1.1 2013/05/23 13:25:30 ryoon Exp $
|
|--- mozilla/image/decoders/nsJPEGDecoder.cpp.orig	2013-05-03 03:07:56.000000000 +0000
|+++ mozilla/image/decoders/nsJPEGDecoder.cpp
--------------------------
Patching file mozilla/image/decoders/nsJPEGDecoder.cpp using Plan A...
Hunk #1 succeeded at 19.
Hunk #2 succeeded at 353.
Hunk #3 succeeded at 362.
Hunk #4 succeeded at 432.
Hunk #5 succeeded at 586.
Hunk #6 succeeded at 900.
done
=> Verifying /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_ios
=> Applying pkgsrc patch /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_ios
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-mozilla_ios,v 1.1 2013/05/23 13:25:30 ryoon Exp $
|
|--- mozilla/ios.orig	2013-05-21 12:42:41.000000000 +0000
|+++ mozilla/ios
--------------------------
(Creating file mozilla/ios...)
Patching file mozilla/ios using Plan A...
Empty context always matches.
Hunk #1 succeeded at 1.
done
=> Verifying /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_ipc_chromium_src_base_message__pump__libevent.cc
=> Applying pkgsrc patch /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_ipc_chromium_src_base_message__pump__libevent.cc
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-mozilla_ipc_chromium_src_base_message__pump__libevent.cc,v 1.1 2013/05/23 13:25:30 ryoon Exp $
|
|--- mozilla/ipc/chromium/src/base/message_pump_libevent.cc.orig	2013-05-03 03:07:57.000000000 +0000
|+++ mozilla/ipc/chromium/src/base/message_pump_libevent.cc
--------------------------
Patching file mozilla/ipc/chromium/src/base/message_pump_libevent.cc using Plan A...
Hunk #1 succeeded at 16.
done
=> Verifying /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_ipc_chromium_src_base_platform__thread__posix.cc
=> Applying pkgsrc patch /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_ipc_chromium_src_base_platform__thread__posix.cc
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-mozilla_ipc_chromium_src_base_platform__thread__posix.cc,v 1.1 2013/05/23 13:25:30 ryoon Exp $
|
|--- mozilla/ipc/chromium/src/base/platform_thread_posix.cc.orig	2013-05-03 03:07:57.000000000 +0000
|+++ mozilla/ipc/chromium/src/base/platform_thread_posix.cc
--------------------------
Patching file mozilla/ipc/chromium/src/base/platform_thread_posix.cc using Plan A...
Hunk #1 succeeded at 10.
done
=> Verifying /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_ipc_glue_GeckoChildProcessHost.cpp
=> Applying pkgsrc patch /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_ipc_glue_GeckoChildProcessHost.cpp
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-mozilla_ipc_glue_GeckoChildProcessHost.cpp,v 1.7 2013/01/20 08:33:14 ryoon Exp $
|
|--- mozilla/ipc/glue/GeckoChildProcessHost.cpp.orig	2013-01-06 06:26:17.000000000 +0000
|+++ mozilla/ipc/glue/GeckoChildProcessHost.cpp
--------------------------
Patching file mozilla/ipc/glue/GeckoChildProcessHost.cpp using Plan A...
Hunk #1 succeeded at 4.
done
=> Verifying /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_ipc_ipdl_ipdl_lower.py
=> Applying pkgsrc patch /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_ipc_ipdl_ipdl_lower.py
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-mozilla_ipc_ipdl_ipdl_lower.py,v 1.1 2013/01/20 08:33:14 ryoon Exp $
|
|--- mozilla/ipc/ipdl/ipdl/lower.py.orig	2013-01-06 06:26:17.000000000 +0000
|+++ mozilla/ipc/ipdl/ipdl/lower.py
--------------------------
Patching file mozilla/ipc/ipdl/ipdl/lower.py using Plan A...
Hunk #1 succeeded at 1799 (offset 2 lines).
done
=> Verifying /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_js_src_Makefile.in
=> Applying pkgsrc patch /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_js_src_Makefile.in
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-mozilla_js_src_Makefile.in,v 1.1 2013/05/23 13:25:30 ryoon Exp $
|
|--- mozilla/js/src/Makefile.in.orig	2013-05-03 03:07:57.000000000 +0000
|+++ mozilla/js/src/Makefile.in
--------------------------
Patching file mozilla/js/src/Makefile.in using Plan A...
Hunk #1 succeeded at 791.
done
=> Verifying /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_js_src_config_system-headers
=> Applying pkgsrc patch /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_js_src_config_system-headers
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-mozilla_js_src_config_system-headers,v 1.6 2013/05/23 13:25:30 ryoon Exp $
|
|--- mozilla/js/src/config/system-headers.orig	2013-05-03 03:07:57.000000000 +0000
|+++ mozilla/js/src/config/system-headers
--------------------------
Patching file mozilla/js/src/config/system-headers using Plan A...
Hunk #1 succeeded at 1126.
done
=> Verifying /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_js_src_jscompartment.h
=> Applying pkgsrc patch /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_js_src_jscompartment.h
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-mozilla_js_src_jscompartment.h,v 1.1 2013/05/23 13:25:30 ryoon Exp $
|
|--- mozilla/js/src/jscompartment.h.orig	2013-05-03 03:07:59.000000000 +0000
|+++ mozilla/js/src/jscompartment.h
--------------------------
Patching file mozilla/js/src/jscompartment.h using Plan A...
Hunk #1 succeeded at 596.
done
=> Verifying /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_js_src_jspropertycacheinlines.h
=> Applying pkgsrc patch /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_js_src_jspropertycacheinlines.h
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-mozilla_js_src_jspropertycacheinlines.h,v 1.1 2013/05/23 13:25:30 ryoon Exp $
|
|--- mozilla/js/src/jspropertycacheinlines.h.orig	2013-05-03 03:07:59.000000000 +0000
|+++ mozilla/js/src/jspropertycacheinlines.h
--------------------------
Patching file mozilla/js/src/jspropertycacheinlines.h using Plan A...
Hunk #1 succeeded at 32.
Hunk #2 succeeded at 65.
done
=> Verifying /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_js_src_methodjit_MethodJIT.cpp
=> Applying pkgsrc patch /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_js_src_methodjit_MethodJIT.cpp
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-mozilla_js_src_methodjit_MethodJIT.cpp,v 1.7 2013/05/23 13:25:30 ryoon Exp $
|
|--- mozilla/js/src/methodjit/MethodJIT.cpp.orig	2013-05-03 03:07:59.000000000 +0000
|+++ mozilla/js/src/methodjit/MethodJIT.cpp
--------------------------
Patching file mozilla/js/src/methodjit/MethodJIT.cpp using Plan A...
Hunk #1 succeeded at 138.
Hunk #2 succeeded at 152.
done
=> Verifying /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_js_src_vm_ObjectImpl-inl.h
=> Applying pkgsrc patch /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_js_src_vm_ObjectImpl-inl.h
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-mozilla_js_src_vm_ObjectImpl-inl.h,v 1.1 2013/05/23 13:25:30 ryoon Exp $
|
|--- mozilla/js/src/vm/ObjectImpl-inl.h.orig	2013-05-03 03:08:00.000000000 +0000
|+++ mozilla/js/src/vm/ObjectImpl-inl.h
--------------------------
Patching file mozilla/js/src/vm/ObjectImpl-inl.h using Plan A...
Hunk #1 succeeded at 164.
Hunk #2 succeeded at 321.
Hunk #3 succeeded at 335.
Hunk #4 succeeded at 362.
done
=> Verifying /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_media_libsoundtouch_src_cpu__detect__x86.cpp
=> Applying pkgsrc patch /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_media_libsoundtouch_src_cpu__detect__x86.cpp
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-mozilla_media_libsoundtouch_src_cpu__detect__x86.cpp,v 1.1 2013/05/23 13:25:30 ryoon Exp $
|
|--- mozilla/media/libsoundtouch/src/cpu_detect_x86.cpp.orig	2013-05-03 03:08:05.000000000 +0000
|+++ mozilla/media/libsoundtouch/src/cpu_detect_x86.cpp
--------------------------
Patching file mozilla/media/libsoundtouch/src/cpu_detect_x86.cpp using Plan A...
Hunk #1 succeeded at 101.
Hunk #2 succeeded at 112.
done
=> Verifying /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_media_mtransport_objs.mk
=> Applying pkgsrc patch /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_media_mtransport_objs.mk
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-mozilla_media_mtransport_objs.mk,v 1.1 2013/05/23 13:25:30 ryoon Exp $
|
|--- mozilla/media/mtransport/objs.mk.orig	2013-05-03 03:08:06.000000000 +0000
|+++ mozilla/media/mtransport/objs.mk
--------------------------
Patching file mozilla/media/mtransport/objs.mk using Plan A...
Hunk #1 succeeded at 23.
done
=> Verifying /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_media_mtransport_test_Makefile.in
=> Applying pkgsrc patch /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_media_mtransport_test_Makefile.in
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-mozilla_media_mtransport_test_Makefile.in,v 1.1 2013/05/23 13:25:30 ryoon Exp $
|
|--- mozilla/media/mtransport/test/Makefile.in.orig	2013-05-03 03:08:06.000000000 +0000
|+++ mozilla/media/mtransport/test/Makefile.in
--------------------------
Patching file mozilla/media/mtransport/test/Makefile.in using Plan A...
Hunk #1 succeeded at 78.
done
=> Verifying /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_media_mtransport_third__party_nICEr_nicer.gyp
=> Applying pkgsrc patch /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_media_mtransport_third__party_nICEr_nicer.gyp
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-mozilla_media_mtransport_third__party_nICEr_nicer.gyp,v 1.1 2013/05/23 13:25:30 ryoon Exp $
|
|--- mozilla/media/mtransport/third_party/nICEr/nicer.gyp.orig	2013-05-03 03:08:06.000000000 +0000
|+++ mozilla/media/mtransport/third_party/nICEr/nicer.gyp
--------------------------
Patching file mozilla/media/mtransport/third_party/nICEr/nicer.gyp using Plan A...
Hunk #1 succeeded at 129.
Hunk #2 succeeded at 149.
done
=> Verifying /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_media_mtransport_third__party_nICEr_src_stun_addrs.c
=> Applying pkgsrc patch /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_media_mtransport_third__party_nICEr_src_stun_addrs.c
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-mozilla_media_mtransport_third__party_nICEr_src_stun_addrs.c,v 1.1 2013/05/23 13:25:30 ryoon Exp $
|
|--- mozilla/media/mtransport/third_party/nICEr/src/stun/addrs.c.orig	2013-05-03 03:08:06.000000000 +0000
|+++ mozilla/media/mtransport/third_party/nICEr/src/stun/addrs.c
--------------------------
Patching file mozilla/media/mtransport/third_party/nICEr/src/stun/addrs.c using Plan A...
Hunk #1 succeeded at 55.
Hunk #2 succeeded at 82.
Hunk #3 succeeded at 692.
done
=> Verifying /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_media_mtransport_third__party_nICEr_src_stun_stun.h
=> Applying pkgsrc patch /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_media_mtransport_third__party_nICEr_src_stun_stun.h
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-mozilla_media_mtransport_third__party_nICEr_src_stun_stun.h,v 1.1 2013/05/23 13:25:30 ryoon Exp $
|
|--- mozilla/media/mtransport/third_party/nICEr/src/stun/stun.h.orig	2013-05-03 03:08:06.000000000 +0000
|+++ mozilla/media/mtransport/third_party/nICEr/src/stun/stun.h
--------------------------
Patching file mozilla/media/mtransport/third_party/nICEr/src/stun/stun.h using Plan A...
Hunk #1 succeeded at 41.
done
=> Verifying /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_media_mtransport_third__party_nICEr_src_util_mbslen.c
=> Applying pkgsrc patch /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_media_mtransport_third__party_nICEr_src_util_mbslen.c
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-mozilla_media_mtransport_third__party_nICEr_src_util_mbslen.c,v 1.1 2013/05/23 13:25:30 ryoon Exp $
|
|--- mozilla/media/mtransport/third_party/nICEr/src/util/mbslen.c.orig	2013-05-03 03:08:06.000000000 +0000
|+++ mozilla/media/mtransport/third_party/nICEr/src/util/mbslen.c
--------------------------
Patching file mozilla/media/mtransport/third_party/nICEr/src/util/mbslen.c using Plan A...
Hunk #1 succeeded at 43.
Hunk #2 succeeded at 62.
Hunk #3 succeeded at 75.
Hunk #4 succeeded at 84.
Hunk #5 succeeded at 106.
done
=> Verifying /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_media_mtransport_third__party_nrappkit_nrappkit.gyp
=> Applying pkgsrc patch /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_media_mtransport_third__party_nrappkit_nrappkit.gyp
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-mozilla_media_mtransport_third__party_nrappkit_nrappkit.gyp,v 1.1 2013/05/23 13:25:30 ryoon Exp $
|
|--- mozilla/media/mtransport/third_party/nrappkit/nrappkit.gyp.orig	2013-05-03 03:08:06.000000000 +0000
|+++ mozilla/media/mtransport/third_party/nrappkit/nrappkit.gyp
--------------------------
Patching file mozilla/media/mtransport/third_party/nrappkit/nrappkit.gyp using Plan A...
Hunk #1 succeeded at 147.
Hunk #2 succeeded at 166.
done
=> Verifying /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_media_mtransport_third__party_nrappkit_src_log_r__log.c
=> Applying pkgsrc patch /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_media_mtransport_third__party_nrappkit_src_log_r__log.c
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-mozilla_media_mtransport_third__party_nrappkit_src_log_r__log.c,v 1.1 2013/05/23 13:25:30 ryoon Exp $
|
|--- mozilla/media/mtransport/third_party/nrappkit/src/log/r_log.c.orig	2013-05-03 03:08:06.000000000 +0000
|+++ mozilla/media/mtransport/third_party/nrappkit/src/log/r_log.c
--------------------------
Patching file mozilla/media/mtransport/third_party/nrappkit/src/log/r_log.c using Plan A...
Hunk #1 succeeded at 48.
done
=> Verifying /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_media_mtransport_third__party_nrappkit_src_port_generic_include_sys_queue.h
=> Applying pkgsrc patch /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_media_mtransport_third__party_nrappkit_src_port_generic_include_sys_queue.h
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-mozilla_media_mtransport_third__party_nrappkit_src_port_generic_include_sys_queue.h,v 1.1 2013/05/23 13:25:30 ryoon Exp $
|
|--- mozilla/media/mtransport/third_party/nrappkit/src/port/generic/include/sys/queue.h.orig	2013-05-03 03:08:06.000000000 +0000
|+++ mozilla/media/mtransport/third_party/nrappkit/src/port/generic/include/sys/queue.h
--------------------------
Patching file mozilla/media/mtransport/third_party/nrappkit/src/port/generic/include/sys/queue.h using Plan A...
Hunk #1 succeeded at 33.
done
=> Verifying /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_media_mtransport_third__party_nrappkit_src_util_util.c
=> Applying pkgsrc patch /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_media_mtransport_third__party_nrappkit_src_util_util.c
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-mozilla_media_mtransport_third__party_nrappkit_src_util_util.c,v 1.1 2013/05/23 13:25:30 ryoon Exp $
|
|--- mozilla/media/mtransport/third_party/nrappkit/src/util/util.c.orig	2013-05-03 03:08:06.000000000 +0000
|+++ mozilla/media/mtransport/third_party/nrappkit/src/util/util.c
--------------------------
Patching file mozilla/media/mtransport/third_party/nrappkit/src/util/util.c using Plan A...
Hunk #1 succeeded at 45.
done
=> Verifying /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_media_webrtc_signaling_signaling.gyp
=> Applying pkgsrc patch /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_media_webrtc_signaling_signaling.gyp
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-mozilla_media_webrtc_signaling_signaling.gyp,v 1.1 2013/05/23 13:25:30 ryoon Exp $
|
|--- mozilla/media/webrtc/signaling/signaling.gyp.orig	2013-05-03 03:08:06.000000000 +0000
|+++ mozilla/media/webrtc/signaling/signaling.gyp
--------------------------
Patching file mozilla/media/webrtc/signaling/signaling.gyp using Plan A...
Hunk #1 succeeded at 217.
Hunk #2 succeeded at 765.
Hunk #3 succeeded at 810.
done
=> Verifying /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_media_webrtc_signaling_src_sipcc_cpr_darwin_cpr__darwin__ipc.c
=> Applying pkgsrc patch /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_media_webrtc_signaling_src_sipcc_cpr_darwin_cpr__darwin__ipc.c
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-mozilla_media_webrtc_signaling_src_sipcc_cpr_darwin_cpr__darwin__ipc.c,v 1.1 2013/05/23 13:25:30 ryoon Exp $
|
|--- mozilla/media/webrtc/signaling/src/sipcc/cpr/darwin/cpr_darwin_ipc.c.orig	2013-05-03 03:08:06.000000000 +0000
|+++ mozilla/media/webrtc/signaling/src/sipcc/cpr/darwin/cpr_darwin_ipc.c
--------------------------
Patching file mozilla/media/webrtc/signaling/src/sipcc/cpr/darwin/cpr_darwin_ipc.c using Plan A...
Hunk #1 succeeded at 322.
done
=> Verifying /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_media_webrtc_signaling_test_Makefile.in
=> Applying pkgsrc patch /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_media_webrtc_signaling_test_Makefile.in
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-mozilla_media_webrtc_signaling_test_Makefile.in,v 1.1 2013/05/23 13:25:30 ryoon Exp $
|
|--- mozilla/media/webrtc/signaling/test/Makefile.in.orig	2013-05-03 03:08:06.000000000 +0000
|+++ mozilla/media/webrtc/signaling/test/Makefile.in
--------------------------
Patching file mozilla/media/webrtc/signaling/test/Makefile.in using Plan A...
Hunk #1 succeeded at 17.
Hunk #2 succeeded at 87.
done
=> Verifying /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_media_webrtc_trunk_build_common.gypi
=> Applying pkgsrc patch /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_media_webrtc_trunk_build_common.gypi
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-mozilla_media_webrtc_trunk_build_common.gypi,v 1.1 2013/05/23 13:25:30 ryoon Exp $
|
|--- mozilla/media/webrtc/trunk/build/common.gypi.orig	2013-05-03 03:08:06.000000000 +0000
|+++ mozilla/media/webrtc/trunk/build/common.gypi
--------------------------
Patching file mozilla/media/webrtc/trunk/build/common.gypi using Plan A...
Hunk #1 succeeded at 80.
Hunk #2 succeeded at 128.
Hunk #3 succeeded at 153.
Hunk #4 succeeded at 416.
done
=> Verifying /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_media_webrtc_trunk_testing_gtest_include_gtest_internal_gtest-port.h
=> Applying pkgsrc patch /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_media_webrtc_trunk_testing_gtest_include_gtest_internal_gtest-port.h
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-mozilla_media_webrtc_trunk_testing_gtest_include_gtest_internal_gtest-port.h,v 1.1 2013/05/23 13:25:30 ryoon Exp $
|
|--- mozilla/media/webrtc/trunk/testing/gtest/include/gtest/internal/gtest-port.h.orig	2013-05-03 03:08:06.000000000 +0000
|+++ mozilla/media/webrtc/trunk/testing/gtest/include/gtest/internal/gtest-port.h
--------------------------
Patching file mozilla/media/webrtc/trunk/testing/gtest/include/gtest/internal/gtest-port.h using Plan A...
Hunk #1 succeeded at 490.
done
=> Verifying /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_media_webrtc_trunk_third__party_libyuv_libyuv.gyp
=> Applying pkgsrc patch /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_media_webrtc_trunk_third__party_libyuv_libyuv.gyp
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-mozilla_media_webrtc_trunk_third__party_libyuv_libyuv.gyp,v 1.1 2013/05/23 13:25:30 ryoon Exp $
|
|--- mozilla/media/webrtc/trunk/third_party/libyuv/libyuv.gyp.orig	2013-05-03 03:08:06.000000000 +0000
|+++ mozilla/media/webrtc/trunk/third_party/libyuv/libyuv.gyp
--------------------------
Patching file mozilla/media/webrtc/trunk/third_party/libyuv/libyuv.gyp using Plan A...
Hunk #1 succeeded at 9.
Hunk #2 succeeded at 51.
done
=> Verifying /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_media_webrtc_trunk_tools_gyp_pylib_gyp_generator_mozmake.py
=> Applying pkgsrc patch /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_media_webrtc_trunk_tools_gyp_pylib_gyp_generator_mozmake.py
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-mozilla_media_webrtc_trunk_tools_gyp_pylib_gyp_generator_mozmake.py,v 1.1 2013/05/23 13:25:30 ryoon Exp $
|
|--- mozilla/media/webrtc/trunk/tools/gyp/pylib/gyp/generator/mozmake.py.orig	2013-05-03 03:08:06.000000000 +0000
|+++ mozilla/media/webrtc/trunk/tools/gyp/pylib/gyp/generator/mozmake.py
--------------------------
Patching file mozilla/media/webrtc/trunk/tools/gyp/pylib/gyp/generator/mozmake.py using Plan A...
Hunk #1 succeeded at 9.
Hunk #2 succeeded at 112.
done
=> Verifying /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_media_webrtc_trunk_webrtc_build_common.gypi
=> Applying pkgsrc patch /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_media_webrtc_trunk_webrtc_build_common.gypi
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-mozilla_media_webrtc_trunk_webrtc_build_common.gypi,v 1.1 2013/05/23 13:25:30 ryoon Exp $
|
|--- mozilla/media/webrtc/trunk/webrtc/build/common.gypi.orig	2013-05-03 03:08:06.000000000 +0000
|+++ mozilla/media/webrtc/trunk/webrtc/build/common.gypi
--------------------------
Patching file mozilla/media/webrtc/trunk/webrtc/build/common.gypi using Plan A...
Hunk #1 succeeded at 124.
Hunk #2 succeeded at 215.
done
=> Verifying /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_media_webrtc_trunk_webrtc_modules_audio__device_audio__device.gypi
=> Applying pkgsrc patch /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_media_webrtc_trunk_webrtc_modules_audio__device_audio__device.gypi
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-mozilla_media_webrtc_trunk_webrtc_modules_audio__device_audio__device.gypi,v 1.1 2013/05/23 13:25:30 ryoon Exp $
|
|--- mozilla/media/webrtc/trunk/webrtc/modules/audio_device/audio_device.gypi.orig	2013-05-03 03:08:07.000000000 +0000
|+++ mozilla/media/webrtc/trunk/webrtc/modules/audio_device/audio_device.gypi
--------------------------
Patching file mozilla/media/webrtc/trunk/webrtc/modules/audio_device/audio_device.gypi using Plan A...
Hunk #1 succeeded at 45.
Hunk #2 succeeded at 81.
Hunk #3 succeeded at 132.
done
=> Verifying /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_media_webrtc_trunk_webrtc_modules_audio__device_audio__device__utility.cc
=> Applying pkgsrc patch /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_media_webrtc_trunk_webrtc_modules_audio__device_audio__device__utility.cc
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-mozilla_media_webrtc_trunk_webrtc_modules_audio__device_audio__device__utility.cc,v 1.1 2013/05/23 13:25:30 ryoon Exp $
|
|--- mozilla/media/webrtc/trunk/webrtc/modules/audio_device/audio_device_utility.cc.orig	2013-05-03 03:08:07.000000000 +0000
|+++ mozilla/media/webrtc/trunk/webrtc/modules/audio_device/audio_device_utility.cc
--------------------------
Patching file mozilla/media/webrtc/trunk/webrtc/modules/audio_device/audio_device_utility.cc using Plan A...
Hunk #1 succeeded at 46.
Hunk #2 succeeded at 109.
done
=> Verifying /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_media_webrtc_trunk_webrtc_modules_rtp__rtcp_source_forward__error__correction.cc
=> Applying pkgsrc patch /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_media_webrtc_trunk_webrtc_modules_rtp__rtcp_source_forward__error__correction.cc
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-mozilla_media_webrtc_trunk_webrtc_modules_rtp__rtcp_source_forward__error__correction.cc,v 1.1 2013/05/23 13:25:30 ryoon Exp $
|
|--- mozilla/media/webrtc/trunk/webrtc/modules/rtp_rtcp/source/forward_error_correction.cc.orig	2013-05-03 03:08:07.000000000 +0000
|+++ mozilla/media/webrtc/trunk/webrtc/modules/rtp_rtcp/source/forward_error_correction.cc
--------------------------
Patching file mozilla/media/webrtc/trunk/webrtc/modules/rtp_rtcp/source/forward_error_correction.cc using Plan A...
Hunk #1 succeeded at 12.
done
=> Verifying /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_media_webrtc_trunk_webrtc_modules_rtp__rtcp_source_rtp__utility.cc
=> Applying pkgsrc patch /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_media_webrtc_trunk_webrtc_modules_rtp__rtcp_source_rtp__utility.cc
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-mozilla_media_webrtc_trunk_webrtc_modules_rtp__rtcp_source_rtp__utility.cc,v 1.1 2013/05/23 13:25:30 ryoon Exp $
|
|--- mozilla/media/webrtc/trunk/webrtc/modules/rtp_rtcp/source/rtp_utility.cc.orig	2013-05-03 03:08:07.000000000 +0000
|+++ mozilla/media/webrtc/trunk/webrtc/modules/rtp_rtcp/source/rtp_utility.cc
--------------------------
Patching file mozilla/media/webrtc/trunk/webrtc/modules/rtp_rtcp/source/rtp_utility.cc using Plan A...
Hunk #1 succeeded at 18.
Hunk #2 succeeded at 156.
Hunk #3 succeeded at 214.
Hunk #4 succeeded at 253.
Hunk #5 succeeded at 330.
done
=> Verifying /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_media_webrtc_trunk_webrtc_modules_udp__transport_source_udp__transport__impl.cc
=> Applying pkgsrc patch /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_media_webrtc_trunk_webrtc_modules_udp__transport_source_udp__transport__impl.cc
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-mozilla_media_webrtc_trunk_webrtc_modules_udp__transport_source_udp__transport__impl.cc,v 1.1 2013/05/23 13:25:30 ryoon Exp $
|
|--- mozilla/media/webrtc/trunk/webrtc/modules/udp_transport/source/udp_transport_impl.cc.orig	2013-05-03 03:08:07.000000000 +0000
|+++ mozilla/media/webrtc/trunk/webrtc/modules/udp_transport/source/udp_transport_impl.cc
--------------------------
Patching file mozilla/media/webrtc/trunk/webrtc/modules/udp_transport/source/udp_transport_impl.cc using Plan A...
Hunk #1 succeeded at 18.
Hunk #2 succeeded at 36.
Hunk #3 succeeded at 53.
Hunk #4 succeeded at 63.
Hunk #5 succeeded at 2373.
Hunk #6 succeeded at 2495.
Hunk #7 succeeded at 2687.
Hunk #8 succeeded at 2826.
done
=> Verifying /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_media_webrtc_trunk_webrtc_modules_utility_source_rtp__dump__impl.cc
=> Applying pkgsrc patch /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_media_webrtc_trunk_webrtc_modules_utility_source_rtp__dump__impl.cc
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-mozilla_media_webrtc_trunk_webrtc_modules_utility_source_rtp__dump__impl.cc,v 1.1 2013/05/23 13:25:30 ryoon Exp $
|
|--- mozilla/media/webrtc/trunk/webrtc/modules/utility/source/rtp_dump_impl.cc.orig	2013-05-03 03:08:07.000000000 +0000
|+++ mozilla/media/webrtc/trunk/webrtc/modules/utility/source/rtp_dump_impl.cc
--------------------------
Patching file mozilla/media/webrtc/trunk/webrtc/modules/utility/source/rtp_dump_impl.cc using Plan A...
Hunk #1 succeeded at 19.
Hunk #2 succeeded at 238.
done
=> Verifying /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_media_webrtc_trunk_webrtc_modules_video__capture_device__info__impl.cc
=> Applying pkgsrc patch /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_media_webrtc_trunk_webrtc_modules_video__capture_device__info__impl.cc
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-mozilla_media_webrtc_trunk_webrtc_modules_video__capture_device__info__impl.cc,v 1.1 2013/05/23 13:25:30 ryoon Exp $
|
|--- mozilla/media/webrtc/trunk/webrtc/modules/video_capture/device_info_impl.cc.orig	2013-05-03 03:08:07.000000000 +0000
|+++ mozilla/media/webrtc/trunk/webrtc/modules/video_capture/device_info_impl.cc
--------------------------
Patching file mozilla/media/webrtc/trunk/webrtc/modules/video_capture/device_info_impl.cc using Plan A...
Hunk #1 succeeded at 54.
Hunk #2 succeeded at 91.
Hunk #3 succeeded at 155.
done
=> Verifying /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_media_webrtc_trunk_webrtc_modules_video__capture_linux_device__info__linux.cc
=> Applying pkgsrc patch /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_media_webrtc_trunk_webrtc_modules_video__capture_linux_device__info__linux.cc
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-mozilla_media_webrtc_trunk_webrtc_modules_video__capture_linux_device__info__linux.cc,v 1.1 2013/05/23 13:25:30 ryoon Exp $
|
|--- mozilla/media/webrtc/trunk/webrtc/modules/video_capture/linux/device_info_linux.cc.orig	2013-05-03 03:08:07.000000000 +0000
|+++ mozilla/media/webrtc/trunk/webrtc/modules/video_capture/linux/device_info_linux.cc
--------------------------
Patching file mozilla/media/webrtc/trunk/webrtc/modules/video_capture/linux/device_info_linux.cc using Plan A...
Hunk #1 succeeded at 19.
Hunk #2 succeeded at 148.
done
=> Verifying /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_media_webrtc_trunk_webrtc_modules_video__capture_linux_video__capture__linux.cc
=> Applying pkgsrc patch /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_media_webrtc_trunk_webrtc_modules_video__capture_linux_video__capture__linux.cc
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-mozilla_media_webrtc_trunk_webrtc_modules_video__capture_linux_video__capture__linux.cc,v 1.1 2013/05/23 13:25:30 ryoon Exp $
|
|--- mozilla/media/webrtc/trunk/webrtc/modules/video_capture/linux/video_capture_linux.cc.orig	2013-05-03 03:08:07.000000000 +0000
|+++ mozilla/media/webrtc/trunk/webrtc/modules/video_capture/linux/video_capture_linux.cc
--------------------------
Patching file mozilla/media/webrtc/trunk/webrtc/modules/video_capture/linux/video_capture_linux.cc using Plan A...
Hunk #1 succeeded at 12.
Hunk #2 succeeded at 37.
done
=> Verifying /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_media_webrtc_trunk_webrtc_modules_video__capture_video__capture.gypi
=> Applying pkgsrc patch /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_media_webrtc_trunk_webrtc_modules_video__capture_video__capture.gypi
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-mozilla_media_webrtc_trunk_webrtc_modules_video__capture_video__capture.gypi,v 1.1 2013/05/23 13:25:30 ryoon Exp $
|
|--- mozilla/media/webrtc/trunk/webrtc/modules/video_capture/video_capture.gypi.orig	2013-05-03 03:08:07.000000000 +0000
|+++ mozilla/media/webrtc/trunk/webrtc/modules/video_capture/video_capture.gypi
--------------------------
Patching file mozilla/media/webrtc/trunk/webrtc/modules/video_capture/video_capture.gypi using Plan A...
Hunk #1 succeeded at 7.
Hunk #2 succeeded at 51.
Hunk #3 succeeded at 170.
Hunk #4 succeeded at 178.
done
=> Verifying /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_media_webrtc_trunk_webrtc_system__wrappers_interface_asm__defines.h
=> Applying pkgsrc patch /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_media_webrtc_trunk_webrtc_system__wrappers_interface_asm__defines.h
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-mozilla_media_webrtc_trunk_webrtc_system__wrappers_interface_asm__defines.h,v 1.1 2013/05/23 13:25:30 ryoon Exp $
|
|--- mozilla/media/webrtc/trunk/webrtc/system_wrappers/interface/asm_defines.h.orig	2013-05-03 03:08:07.000000000 +0000
|+++ mozilla/media/webrtc/trunk/webrtc/system_wrappers/interface/asm_defines.h
--------------------------
Patching file mozilla/media/webrtc/trunk/webrtc/system_wrappers/interface/asm_defines.h using Plan A...
Hunk #1 succeeded at 11.
done
=> Verifying /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_media_webrtc_trunk_webrtc_system__wrappers_interface_tick__util.h
=> Applying pkgsrc patch /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_media_webrtc_trunk_webrtc_system__wrappers_interface_tick__util.h
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-mozilla_media_webrtc_trunk_webrtc_system__wrappers_interface_tick__util.h,v 1.1 2013/05/23 13:25:30 ryoon Exp $
|
|--- mozilla/media/webrtc/trunk/webrtc/system_wrappers/interface/tick_util.h.orig	2013-05-03 03:08:07.000000000 +0000
|+++ mozilla/media/webrtc/trunk/webrtc/system_wrappers/interface/tick_util.h
--------------------------
Patching file mozilla/media/webrtc/trunk/webrtc/system_wrappers/interface/tick_util.h using Plan A...
Hunk #1 succeeded at 194.
Hunk #2 succeeded at 241.
Hunk #3 succeeded at 258.
Hunk #4 succeeded at 278.
Hunk #5 succeeded at 294.
Hunk #6 succeeded at 323.
Hunk #7 succeeded at 342.
done
=> Verifying /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_media_webrtc_trunk_webrtc_system__wrappers_source_atomic32__posix.cc
=> Applying pkgsrc patch /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_media_webrtc_trunk_webrtc_system__wrappers_source_atomic32__posix.cc
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-mozilla_media_webrtc_trunk_webrtc_system__wrappers_source_atomic32__posix.cc,v 1.1 2013/05/23 13:25:30 ryoon Exp $
|
|--- mozilla/media/webrtc/trunk/webrtc/system_wrappers/source/atomic32_posix.cc.orig	2013-05-03 03:08:07.000000000 +0000
|+++ mozilla/media/webrtc/trunk/webrtc/system_wrappers/source/atomic32_posix.cc
--------------------------
Patching file mozilla/media/webrtc/trunk/webrtc/system_wrappers/source/atomic32_posix.cc using Plan A...
Hunk #1 succeeded at 12.
done
=> Verifying /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_media_webrtc_trunk_webrtc_system__wrappers_source_condition__variable.cc
=> Applying pkgsrc patch /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_media_webrtc_trunk_webrtc_system__wrappers_source_condition__variable.cc
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-mozilla_media_webrtc_trunk_webrtc_system__wrappers_source_condition__variable.cc,v 1.1 2013/05/23 13:25:30 ryoon Exp $
|
|--- mozilla/media/webrtc/trunk/webrtc/system_wrappers/source/condition_variable.cc.orig	2013-05-03 03:08:07.000000000 +0000
|+++ mozilla/media/webrtc/trunk/webrtc/system_wrappers/source/condition_variable.cc
--------------------------
Patching file mozilla/media/webrtc/trunk/webrtc/system_wrappers/source/condition_variable.cc using Plan A...
Hunk #1 succeeded at 8.
Hunk #2 succeeded at 25.
done
=> Verifying /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_media_webrtc_trunk_webrtc_system__wrappers_source_condition__variable__posix.cc
=> Applying pkgsrc patch /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_media_webrtc_trunk_webrtc_system__wrappers_source_condition__variable__posix.cc
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-mozilla_media_webrtc_trunk_webrtc_system__wrappers_source_condition__variable__posix.cc,v 1.1 2013/05/23 13:25:30 ryoon Exp $
|
|--- mozilla/media/webrtc/trunk/webrtc/system_wrappers/source/condition_variable_posix.cc.orig	2013-05-03 03:08:07.000000000 +0000
|+++ mozilla/media/webrtc/trunk/webrtc/system_wrappers/source/condition_variable_posix.cc
--------------------------
Patching file mozilla/media/webrtc/trunk/webrtc/system_wrappers/source/condition_variable_posix.cc using Plan A...
Hunk #1 succeeded at 79.
done
=> Verifying /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_media_webrtc_trunk_webrtc_system__wrappers_source_cpu.cc
=> Applying pkgsrc patch /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_media_webrtc_trunk_webrtc_system__wrappers_source_cpu.cc
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-mozilla_media_webrtc_trunk_webrtc_system__wrappers_source_cpu.cc,v 1.1 2013/05/23 13:25:30 ryoon Exp $
|
|--- mozilla/media/webrtc/trunk/webrtc/system_wrappers/source/cpu.cc.orig	2013-05-03 03:08:07.000000000 +0000
|+++ mozilla/media/webrtc/trunk/webrtc/system_wrappers/source/cpu.cc
--------------------------
Patching file mozilla/media/webrtc/trunk/webrtc/system_wrappers/source/cpu.cc using Plan A...
Hunk #1 succeeded at 14.
Hunk #2 succeeded at 26.
done
=> Verifying /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_media_webrtc_trunk_webrtc_system__wrappers_source_cpu__info.cc
=> Applying pkgsrc patch /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_media_webrtc_trunk_webrtc_system__wrappers_source_cpu__info.cc
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-mozilla_media_webrtc_trunk_webrtc_system__wrappers_source_cpu__info.cc,v 1.1 2013/05/23 13:25:30 ryoon Exp $
|
|--- mozilla/media/webrtc/trunk/webrtc/system_wrappers/source/cpu_info.cc.orig	2013-05-03 03:08:07.000000000 +0000
|+++ mozilla/media/webrtc/trunk/webrtc/system_wrappers/source/cpu_info.cc
--------------------------
Patching file mozilla/media/webrtc/trunk/webrtc/system_wrappers/source/cpu_info.cc using Plan A...
Hunk #1 succeeded at 12.
Hunk #2 succeeded at 43.
Hunk #3 succeeded at 63.
done
=> Verifying /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_media_webrtc_trunk_webrtc_system__wrappers_source_spreadsortlib_spreadsort.hpp
=> Applying pkgsrc patch /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_media_webrtc_trunk_webrtc_system__wrappers_source_spreadsortlib_spreadsort.hpp
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-mozilla_media_webrtc_trunk_webrtc_system__wrappers_source_spreadsortlib_spreadsort.hpp,v 1.1 2013/05/23 13:25:30 ryoon Exp $
|
|--- mozilla/media/webrtc/trunk/webrtc/system_wrappers/source/spreadsortlib/spreadsort.hpp.orig	2013-05-03 03:08:07.000000000 +0000
|+++ mozilla/media/webrtc/trunk/webrtc/system_wrappers/source/spreadsortlib/spreadsort.hpp
--------------------------
Patching file mozilla/media/webrtc/trunk/webrtc/system_wrappers/source/spreadsortlib/spreadsort.hpp using Plan A...
Hunk #1 succeeded at 21.
done
=> Verifying /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_media_webrtc_trunk_webrtc_system__wrappers_source_thread__posix.cc
=> Applying pkgsrc patch /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_media_webrtc_trunk_webrtc_system__wrappers_source_thread__posix.cc
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-mozilla_media_webrtc_trunk_webrtc_system__wrappers_source_thread__posix.cc,v 1.1 2013/05/23 13:25:30 ryoon Exp $
|
|--- mozilla/media/webrtc/trunk/webrtc/system_wrappers/source/thread_posix.cc.orig	2013-05-03 03:08:07.000000000 +0000
|+++ mozilla/media/webrtc/trunk/webrtc/system_wrappers/source/thread_posix.cc
--------------------------
Patching file mozilla/media/webrtc/trunk/webrtc/system_wrappers/source/thread_posix.cc using Plan A...
Hunk #1 succeeded at 59.
Hunk #2 succeeded at 152.
Hunk #3 succeeded at 197.
Hunk #4 succeeded at 262.
Hunk #5 succeeded at 281.
Hunk #6 succeeded at 359.
done
=> Verifying /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_media_webrtc_trunk_webrtc_system__wrappers_source_trace__posix.cc
=> Applying pkgsrc patch /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_media_webrtc_trunk_webrtc_system__wrappers_source_trace__posix.cc
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-mozilla_media_webrtc_trunk_webrtc_system__wrappers_source_trace__posix.cc,v 1.1 2013/05/23 13:25:30 ryoon Exp $
|
|--- mozilla/media/webrtc/trunk/webrtc/system_wrappers/source/trace_posix.cc.orig	2013-05-03 03:08:07.000000000 +0000
|+++ mozilla/media/webrtc/trunk/webrtc/system_wrappers/source/trace_posix.cc
--------------------------
Patching file mozilla/media/webrtc/trunk/webrtc/system_wrappers/source/trace_posix.cc using Plan A...
Hunk #1 succeeded at 54.
done
=> Verifying /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_media_webrtc_trunk_webrtc_typedefs.h
=> Applying pkgsrc patch /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_media_webrtc_trunk_webrtc_typedefs.h
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-mozilla_media_webrtc_trunk_webrtc_typedefs.h,v 1.1 2013/05/23 13:25:30 ryoon Exp $
|
|--- mozilla/media/webrtc/trunk/webrtc/typedefs.h.orig	2013-05-03 03:08:07.000000000 +0000
|+++ mozilla/media/webrtc/trunk/webrtc/typedefs.h
--------------------------
Patching file mozilla/media/webrtc/trunk/webrtc/typedefs.h using Plan A...
Hunk #1 succeeded at 21.
done
=> Verifying /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_media_webrtc_trunk_webrtc_video__engine_vie__defines.h
=> Applying pkgsrc patch /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_media_webrtc_trunk_webrtc_video__engine_vie__defines.h
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-mozilla_media_webrtc_trunk_webrtc_video__engine_vie__defines.h,v 1.1 2013/05/23 13:25:30 ryoon Exp $
|
|--- mozilla/media/webrtc/trunk/webrtc/video_engine/vie_defines.h.orig	2013-05-03 03:08:07.000000000 +0000
|+++ mozilla/media/webrtc/trunk/webrtc/video_engine/vie_defines.h
--------------------------
Patching file mozilla/media/webrtc/trunk/webrtc/video_engine/vie_defines.h using Plan A...
Hunk #1 succeeded at 173.
done
=> Verifying /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_media_webrtc_trunk_webrtc_voice__engine_voe__network__impl.cc
=> Applying pkgsrc patch /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_media_webrtc_trunk_webrtc_voice__engine_voe__network__impl.cc
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-mozilla_media_webrtc_trunk_webrtc_voice__engine_voe__network__impl.cc,v 1.1 2013/05/23 13:25:30 ryoon Exp $
|
|--- mozilla/media/webrtc/trunk/webrtc/voice_engine/voe_network_impl.cc.orig	2013-05-03 03:08:07.000000000 +0000
|+++ mozilla/media/webrtc/trunk/webrtc/voice_engine/voe_network_impl.cc
--------------------------
Patching file mozilla/media/webrtc/trunk/webrtc/voice_engine/voe_network_impl.cc using Plan A...
Hunk #1 succeeded at 472.
Hunk #2 succeeded at 528.
Hunk #3 succeeded at 551.
done
=> Verifying /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_media_webrtc_trunk_webrtc_voice__engine_voice__engine__defines.h
=> Applying pkgsrc patch /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_media_webrtc_trunk_webrtc_voice__engine_voice__engine__defines.h
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-mozilla_media_webrtc_trunk_webrtc_voice__engine_voice__engine__defines.h,v 1.1 2013/05/23 13:25:30 ryoon Exp $
|
|--- mozilla/media/webrtc/trunk/webrtc/voice_engine/voice_engine_defines.h.orig	2013-05-03 03:08:07.000000000 +0000
|+++ mozilla/media/webrtc/trunk/webrtc/voice_engine/voice_engine_defines.h
--------------------------
Patching file mozilla/media/webrtc/trunk/webrtc/voice_engine/voice_engine_defines.h using Plan A...
Hunk #1 succeeded at 414.
Hunk #2 succeeded at 431.
Hunk #3 succeeded at 440.
Hunk #4 succeeded at 533.
done
=> Verifying /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_media_webrtc_webrtc__config.gypi
=> Applying pkgsrc patch /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_media_webrtc_webrtc__config.gypi
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-mozilla_media_webrtc_webrtc__config.gypi,v 1.1 2013/05/23 13:25:30 ryoon Exp $
|
|--- mozilla/media/webrtc/webrtc_config.gypi.orig	2013-05-03 03:08:07.000000000 +0000
|+++ mozilla/media/webrtc/webrtc_config.gypi
--------------------------
Patching file mozilla/media/webrtc/webrtc_config.gypi using Plan A...
Hunk #1 succeeded at 14.
done
=> Verifying /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_netwerk_sctp_src_Makefile.in
=> Applying pkgsrc patch /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_netwerk_sctp_src_Makefile.in
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-mozilla_netwerk_sctp_src_Makefile.in,v 1.1 2013/05/23 13:25:30 ryoon Exp $
|
|--- mozilla/netwerk/sctp/src/Makefile.in.orig	2013-05-03 03:08:09.000000000 +0000
|+++ mozilla/netwerk/sctp/src/Makefile.in
--------------------------
Patching file mozilla/netwerk/sctp/src/Makefile.in using Plan A...
Hunk #1 succeeded at 114.
done
=> Verifying /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_netwerk_sctp_src_netinet_sctp__os__userspace.h
=> Applying pkgsrc patch /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_netwerk_sctp_src_netinet_sctp__os__userspace.h
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-mozilla_netwerk_sctp_src_netinet_sctp__os__userspace.h,v 1.1 2013/05/23 13:25:30 ryoon Exp $
|
|--- mozilla/netwerk/sctp/src/netinet/sctp_os_userspace.h.orig	2013-05-03 03:08:09.000000000 +0000
|+++ mozilla/netwerk/sctp/src/netinet/sctp_os_userspace.h
--------------------------
Patching file mozilla/netwerk/sctp/src/netinet/sctp_os_userspace.h using Plan A...
Hunk #1 succeeded at 395.
done
=> Verifying /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_netwerk_sctp_src_user__recv__thread.c
=> Applying pkgsrc patch /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_netwerk_sctp_src_user__recv__thread.c
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-mozilla_netwerk_sctp_src_user__recv__thread.c,v 1.1 2013/05/23 13:25:30 ryoon Exp $
|
|--- mozilla/netwerk/sctp/src/user_recv_thread.c.orig	2013-05-03 03:08:09.000000000 +0000
|+++ mozilla/netwerk/sctp/src/user_recv_thread.c
--------------------------
Patching file mozilla/netwerk/sctp/src/user_recv_thread.c using Plan A...
Hunk #1 succeeded at 35.
done
=> Verifying /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_netwerk_sctp_src_user__socketvar.h
=> Applying pkgsrc patch /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_netwerk_sctp_src_user__socketvar.h
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-mozilla_netwerk_sctp_src_user__socketvar.h,v 1.1 2013/05/23 13:25:30 ryoon Exp $
|
|--- mozilla/netwerk/sctp/src/user_socketvar.h.orig	2013-05-03 03:08:09.000000000 +0000
|+++ mozilla/netwerk/sctp/src/user_socketvar.h
--------------------------
Patching file mozilla/netwerk/sctp/src/user_socketvar.h using Plan A...
Hunk #1 succeeded at 47.
Hunk #2 succeeded at 64.
done
=> Verifying /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_ostream
=> Applying pkgsrc patch /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_ostream
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-mozilla_ostream,v 1.1 2013/05/23 13:25:30 ryoon Exp $
|
|--- mozilla/ostream.orig	2013-05-21 12:42:41.000000000 +0000
|+++ mozilla/ostream
--------------------------
(Creating file mozilla/ostream...)
Patching file mozilla/ostream using Plan A...
Empty context always matches.
Hunk #1 succeeded at 1.
done
=> Verifying /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_security_manager_ssl_src_nsNSSComponent.cpp
=> Applying pkgsrc patch /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_security_manager_ssl_src_nsNSSComponent.cpp
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-mozilla_security_manager_ssl_src_nsNSSComponent.cpp,v 1.1 2013/05/23 13:25:30 ryoon Exp $
|
|--- mozilla/security/manager/ssl/src/nsNSSComponent.cpp.orig	2013-05-03 03:08:10.000000000 +0000
|+++ mozilla/security/manager/ssl/src/nsNSSComponent.cpp
--------------------------
Patching file mozilla/security/manager/ssl/src/nsNSSComponent.cpp using Plan A...
Hunk #1 succeeded at 72.
done
=> Verifying /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_toolkit_library_Makefile.in
=> Applying pkgsrc patch /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_toolkit_library_Makefile.in
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-mozilla_toolkit_library_Makefile.in,v 1.1 2013/05/23 13:25:30 ryoon Exp $
|
|--- mozilla/toolkit/library/Makefile.in.orig	2013-05-03 03:08:13.000000000 +0000
|+++ mozilla/toolkit/library/Makefile.in
--------------------------
Patching file mozilla/toolkit/library/Makefile.in using Plan A...
Hunk #1 succeeded at 405.
done
=> Verifying /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_unwind.h
=> Applying pkgsrc patch /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_unwind.h
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-mozilla_unwind.h,v 1.1 2013/05/23 13:25:30 ryoon Exp $
|
|--- mozilla/unwind.h.orig	2013-05-21 12:42:41.000000000 +0000
|+++ mozilla/unwind.h
--------------------------
(Creating file mozilla/unwind.h...)
Patching file mozilla/unwind.h using Plan A...
Empty context always matches.
Hunk #1 succeeded at 1.
done
=> Verifying /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_xpcom_Makefile.in
=> Applying pkgsrc patch /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_xpcom_Makefile.in
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-mozilla_xpcom_Makefile.in,v 1.8 2013/05/23 13:25:30 ryoon Exp $
|
|--- mozilla/xpcom/Makefile.in.orig	2013-05-03 03:08:15.000000000 +0000
|+++ mozilla/xpcom/Makefile.in
--------------------------
Patching file mozilla/xpcom/Makefile.in using Plan A...
Hunk #1 succeeded at 35.
done
=> Verifying /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_xpcom_ds_TimeStamp.h
=> Applying pkgsrc patch /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_xpcom_ds_TimeStamp.h
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-mozilla_xpcom_ds_TimeStamp.h,v 1.1 2013/01/20 08:33:14 ryoon Exp $
|
|--- mozilla/xpcom/ds/TimeStamp.h.orig	2013-01-06 06:26:33.000000000 +0000
|+++ mozilla/xpcom/ds/TimeStamp.h
--------------------------
Patching file mozilla/xpcom/ds/TimeStamp.h using Plan A...
Hunk #1 succeeded at 151 (offset 21 lines).
done
=> Verifying /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_xpcom_io_nsMultiplexInputStream.cpp
=> Applying pkgsrc patch /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_xpcom_io_nsMultiplexInputStream.cpp
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-mozilla_xpcom_io_nsMultiplexInputStream.cpp,v 1.1 2013/05/23 13:25:30 ryoon Exp $
|
|--- mozilla/xpcom/io/nsMultiplexInputStream.cpp.orig	2013-05-03 03:08:15.000000000 +0000
|+++ mozilla/xpcom/io/nsMultiplexInputStream.cpp
--------------------------
Patching file mozilla/xpcom/io/nsMultiplexInputStream.cpp using Plan A...
Hunk #1 succeeded at 529.
done
=> Verifying /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_xpcom_reflect_xptcall_src_md_unix_xptcinvoke__gcc__x86__unix.cpp
=> Applying pkgsrc patch /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_xpcom_reflect_xptcall_src_md_unix_xptcinvoke__gcc__x86__unix.cpp
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-mozilla_xpcom_reflect_xptcall_src_md_unix_xptcinvoke__gcc__x86__unix.cpp,v 1.1 2013/05/23 13:25:30 ryoon Exp $
|
|--- mozilla/xpcom/reflect/xptcall/src/md/unix/xptcinvoke_gcc_x86_unix.cpp.orig	2013-05-03 03:08:15.000000000 +0000
|+++ mozilla/xpcom/reflect/xptcall/src/md/unix/xptcinvoke_gcc_x86_unix.cpp
--------------------------
Patching file mozilla/xpcom/reflect/xptcall/src/md/unix/xptcinvoke_gcc_x86_unix.cpp using Plan A...
Hunk #1 succeeded at 9.
done
=> Verifying /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_xpcom_reflect_xptcall_src_md_unix_xptcinvoke__ppc__netbsd.cpp
=> Applying pkgsrc patch /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_xpcom_reflect_xptcall_src_md_unix_xptcinvoke__ppc__netbsd.cpp
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-mozilla_xpcom_reflect_xptcall_src_md_unix_xptcinvoke__ppc__netbsd.cpp,v 1.2 2013/01/07 21:55:30 ryoon Exp $
|
|--- mozilla/xpcom/reflect/xptcall/src/md/unix/xptcinvoke_ppc_netbsd.cpp.orig	2012-11-18 10:19:54.000000000 +0000
|+++ mozilla/xpcom/reflect/xptcall/src/md/unix/xptcinvoke_ppc_netbsd.cpp
--------------------------
Patching file mozilla/xpcom/reflect/xptcall/src/md/unix/xptcinvoke_ppc_netbsd.cpp using Plan A...
Hunk #1 succeeded at 5.
Hunk #2 succeeded at 69.
Hunk #3 succeeded at 81.
Hunk #4 succeeded at 111.
done
=> Verifying /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_xpcom_reflect_xptcall_src_md_unix_xptcstubs__gcc__x86__unix.cpp
=> Applying pkgsrc patch /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_xpcom_reflect_xptcall_src_md_unix_xptcstubs__gcc__x86__unix.cpp
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-mozilla_xpcom_reflect_xptcall_src_md_unix_xptcstubs__gcc__x86__unix.cpp,v 1.1 2013/05/23 13:25:30 ryoon Exp $
|
|--- mozilla/xpcom/reflect/xptcall/src/md/unix/xptcstubs_gcc_x86_unix.cpp.orig	2013-05-03 03:08:15.000000000 +0000
|+++ mozilla/xpcom/reflect/xptcall/src/md/unix/xptcstubs_gcc_x86_unix.cpp
--------------------------
Patching file mozilla/xpcom/reflect/xptcall/src/md/unix/xptcstubs_gcc_x86_unix.cpp using Plan A...
Hunk #1 succeeded at 10.
done
=> Verifying /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_xpcom_string_public_nsAlgorithm.h
=> Applying pkgsrc patch /usr/pkgsrc/www/seamonkey/patches/patch-mozilla_xpcom_string_public_nsAlgorithm.h
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-mozilla_xpcom_string_public_nsAlgorithm.h,v 1.1 2013/05/23 13:25:30 ryoon Exp $
|
|--- mozilla/xpcom/string/public/nsAlgorithm.h.orig	2013-05-03 03:08:15.000000000 +0000
|+++ mozilla/xpcom/string/public/nsAlgorithm.h
--------------------------
Patching file mozilla/xpcom/string/public/nsAlgorithm.h using Plan A...
Hunk #1 succeeded at 45.
done
=> Verifying /usr/pkgsrc/www/seamonkey/patches/patch-mp
=> Applying pkgsrc patch /usr/pkgsrc/www/seamonkey/patches/patch-mp
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-mp,v 1.12 2013/05/23 13:25:30 ryoon Exp $
|
|--- mozilla/media/libsydneyaudio/src/Makefile.in.orig	2013-05-03 03:08:05.000000000 +0000
|+++ mozilla/media/libsydneyaudio/src/Makefile.in
--------------------------
Patching file mozilla/media/libsydneyaudio/src/Makefile.in using Plan A...
Hunk #1 succeeded at 70.
done
=> Verifying /usr/pkgsrc/www/seamonkey/patches/patch-pa
=> Applying pkgsrc patch /usr/pkgsrc/www/seamonkey/patches/patch-pa
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-pa,v 1.8 2013/01/07 21:55:30 ryoon Exp $
|
|--- mozilla/xulrunner/installer/mozilla-js.pc.in.orig	2012-11-18 10:19:54.000000000 +0000
|+++ mozilla/xulrunner/installer/mozilla-js.pc.in
--------------------------
Patching file mozilla/xulrunner/installer/mozilla-js.pc.in using Plan A...
Hunk #1 succeeded at 6.
done
=> Verifying /usr/pkgsrc/www/seamonkey/patches/patch-pb
=> Applying pkgsrc patch /usr/pkgsrc/www/seamonkey/patches/patch-pb
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-pb,v 1.8 2013/01/07 21:55:30 ryoon Exp $
|
|--- mozilla/xulrunner/installer/libxul.pc.in.orig	2012-11-18 10:19:54.000000000 +0000
|+++ mozilla/xulrunner/installer/libxul.pc.in
--------------------------
Patching file mozilla/xulrunner/installer/libxul.pc.in using Plan A...
Hunk #1 succeeded at 7.
done
=> Verifying /usr/pkgsrc/www/seamonkey/patches/patch-pc
=> Applying pkgsrc patch /usr/pkgsrc/www/seamonkey/patches/patch-pc
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-pc,v 1.8 2013/01/07 21:55:30 ryoon Exp $
|
|--- mozilla/xulrunner/installer/libxul-embedding.pc.in.orig	2012-11-18 10:19:54.000000000 +0000
|+++ mozilla/xulrunner/installer/libxul-embedding.pc.in
--------------------------
Patching file mozilla/xulrunner/installer/libxul-embedding.pc.in using Plan A...
Hunk #1 succeeded at 6.
done
=> Verifying /usr/pkgsrc/www/seamonkey/patches/patch-pd
=> Applying pkgsrc patch /usr/pkgsrc/www/seamonkey/patches/patch-pd
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-pd,v 1.9 2013/01/20 08:33:14 ryoon Exp $
|
|--- mozilla/xulrunner/installer/mozilla-nss.pc.in.orig	2013-01-06 06:26:34.000000000 +0000
|+++ mozilla/xulrunner/installer/mozilla-nss.pc.in
--------------------------
Patching file mozilla/xulrunner/installer/mozilla-nss.pc.in using Plan A...
Hunk #1 succeeded at 6.
done
=> Verifying /usr/pkgsrc/www/seamonkey/patches/patch-pg
=> Applying pkgsrc patch /usr/pkgsrc/www/seamonkey/patches/patch-pg
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-pg,v 1.8 2013/01/07 21:55:30 ryoon Exp $
|
|--- mozilla/xulrunner/installer/mozilla-nspr.pc.in.orig	2012-11-18 10:19:54.000000000 +0000
|+++ mozilla/xulrunner/installer/mozilla-nspr.pc.in
--------------------------
Patching file mozilla/xulrunner/installer/mozilla-nspr.pc.in using Plan A...
Hunk #1 succeeded at 5.
done
=> Verifying /usr/pkgsrc/www/seamonkey/patches/patch-rc
=> Applying pkgsrc patch /usr/pkgsrc/www/seamonkey/patches/patch-rc
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-rc,v 1.8 2013/01/07 21:55:30 ryoon Exp $
|
|--- mozilla/browser/branding/unofficial/locales/en-US/brand.dtd.orig	2012-11-18 10:19:30.000000000 +0000
|+++ mozilla/browser/branding/unofficial/locales/en-US/brand.dtd
--------------------------
Patching file mozilla/browser/branding/unofficial/locales/en-US/brand.dtd using Plan A...
Hunk #1 succeeded at 2.
done
=> Verifying /usr/pkgsrc/www/seamonkey/patches/patch-suite_confvars.sh
=> Applying pkgsrc patch /usr/pkgsrc/www/seamonkey/patches/patch-suite_confvars.sh
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-suite_confvars.sh,v 1.1 2013/05/23 13:25:30 ryoon Exp $
|
|--- suite/confvars.sh.orig	2013-05-03 03:02:30.000000000 +0000
|+++ suite/confvars.sh
--------------------------
Patching file suite/confvars.sh using Plan A...
Hunk #1 succeeded at 38.
done
=> Verifying /usr/pkgsrc/www/seamonkey/patches/patch-suite_installer_Makefile.in
=> Applying pkgsrc patch /usr/pkgsrc/www/seamonkey/patches/patch-suite_installer_Makefile.in
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-suite_installer_Makefile.in,v 1.4 2013/01/07 21:55:30 ryoon Exp $
|
|--- suite/installer/Makefile.in.orig	2012-11-18 10:14:25.000000000 +0000
|+++ suite/installer/Makefile.in
--------------------------
Patching file suite/installer/Makefile.in using Plan A...
Hunk #1 succeeded at 16.
done
=> Verifying /usr/pkgsrc/www/seamonkey/patches/patch-suite_installer_package-manifest.in
=> Applying pkgsrc patch /usr/pkgsrc/www/seamonkey/patches/patch-suite_installer_package-manifest.in
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-suite_installer_package-manifest.in,v 1.3 2013/01/07 21:55:30 ryoon Exp $
|
|--- suite/installer/package-manifest.in.orig	2012-11-18 10:14:25.000000000 +0000
|+++ suite/installer/package-manifest.in
--------------------------
Patching file suite/installer/package-manifest.in using Plan A...
Hunk #1 succeeded at 873.
done
=> Verifying /usr/pkgsrc/www/seamonkey/patches/patch-toolkit_toolkit-tiers.mk
=> Applying pkgsrc patch /usr/pkgsrc/www/seamonkey/patches/patch-toolkit_toolkit-tiers.mk
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-toolkit_toolkit-tiers.mk,v 1.7 2013/01/07 21:55:30 ryoon Exp $
|
|--- mozilla/toolkit/toolkit-tiers.mk.orig	2012-11-18 10:19:53.000000000 +0000
|+++ mozilla/toolkit/toolkit-tiers.mk
--------------------------
Patching file mozilla/toolkit/toolkit-tiers.mk using Plan A...
Hunk #1 succeeded at 63 (offset 20 lines).
done
=> Verifying /usr/pkgsrc/www/seamonkey/patches/patch-xa
=> Applying pkgsrc patch /usr/pkgsrc/www/seamonkey/patches/patch-xa
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-xa,v 1.7 2013/01/07 21:55:30 ryoon Exp $
|
|NetBSD/sparc64 xptcall support code. From pkgsrc/www/firefox3/files/
|
|--- mozilla/xpcom/reflect/xptcall/src/md/unix/xptcinvoke_asm_sparc64_netbsd.s.orig	2012-11-23 07:42:33.000000000 +0000
|+++ mozilla/xpcom/reflect/xptcall/src/md/unix/xptcinvoke_asm_sparc64_netbsd.s
--------------------------
(Creating file mozilla/xpcom/reflect/xptcall/src/md/unix/xptcinvoke_asm_sparc64_netbsd.s...)
Patching file mozilla/xpcom/reflect/xptcall/src/md/unix/xptcinvoke_asm_sparc64_netbsd.s using Plan A...
Empty context always matches.
Hunk #1 succeeded at 1.
done
=> Verifying /usr/pkgsrc/www/seamonkey/patches/patch-xb
=> Applying pkgsrc patch /usr/pkgsrc/www/seamonkey/patches/patch-xb
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-xb,v 1.7 2013/01/07 21:55:30 ryoon Exp $
|
|NetBSD/sparc64 xptcall support code. From pkgsrc/www/firefox3/files/
|
|--- mozilla/xpcom/reflect/xptcall/src/md/unix/xptcinvoke_sparc64_netbsd.cpp.orig	2012-11-23 07:42:43.000000000 +0000
|+++ mozilla/xpcom/reflect/xptcall/src/md/unix/xptcinvoke_sparc64_netbsd.cpp
--------------------------
(Creating file mozilla/xpcom/reflect/xptcall/src/md/unix/xptcinvoke_sparc64_netbsd.cpp...)
Patching file mozilla/xpcom/reflect/xptcall/src/md/unix/xptcinvoke_sparc64_netbsd.cpp using Plan A...
Empty context always matches.
Hunk #1 succeeded at 1.
done
=> Verifying /usr/pkgsrc/www/seamonkey/patches/patch-xc
=> Applying pkgsrc patch /usr/pkgsrc/www/seamonkey/patches/patch-xc
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-xc,v 1.7 2013/01/07 21:55:30 ryoon Exp $
|
|NetBSD/sparc64 xptcall support code. From pkgsrc/www/firefox3/files/
|
|--- mozilla/xpcom/reflect/xptcall/src/md/unix/xptcstubs_asm_sparc64_netbsd.s.orig	2012-11-23 07:42:48.000000000 +0000
|+++ mozilla/xpcom/reflect/xptcall/src/md/unix/xptcstubs_asm_sparc64_netbsd.s
--------------------------
(Creating file mozilla/xpcom/reflect/xptcall/src/md/unix/xptcstubs_asm_sparc64_netbsd.s...)
Patching file mozilla/xpcom/reflect/xptcall/src/md/unix/xptcstubs_asm_sparc64_netbsd.s using Plan A...
Empty context always matches.
Hunk #1 succeeded at 1.
done
=> Verifying /usr/pkgsrc/www/seamonkey/patches/patch-xd
=> Applying pkgsrc patch /usr/pkgsrc/www/seamonkey/patches/patch-xd
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-xd,v 1.7 2013/01/07 21:55:30 ryoon Exp $
|
|NetBSD/sparc64 xptcall support code. From pkgsrc/www/firefox3/files/
|
|--- mozilla/xpcom/reflect/xptcall/src/md/unix/xptcstubs_sparc64_netbsd.cpp.orig	2012-11-23 07:42:53.000000000 +0000
|+++ mozilla/xpcom/reflect/xptcall/src/md/unix/xptcstubs_sparc64_netbsd.cpp
--------------------------
(Creating file mozilla/xpcom/reflect/xptcall/src/md/unix/xptcstubs_sparc64_netbsd.cpp...)
Patching file mozilla/xpcom/reflect/xptcall/src/md/unix/xptcstubs_sparc64_netbsd.cpp using Plan A...
Empty context always matches.
Hunk #1 succeeded at 1.
done
=> Verifying /usr/pkgsrc/www/seamonkey/patches/patch-xe
=> Applying pkgsrc patch /usr/pkgsrc/www/seamonkey/patches/patch-xe
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-xe,v 1.7 2013/01/07 21:55:30 ryoon Exp $
|
| NetBSD/m68k xptcall support code. From pkgsrc/www/firefox/patch-ad.
|
|--- mozilla/xpcom/reflect/xptcall/src/md/unix/xptcinvoke_netbsd_m68k.cpp.orig	2012-11-18 10:19:54.000000000 +0000
|+++ mozilla/xpcom/reflect/xptcall/src/md/unix/xptcinvoke_netbsd_m68k.cpp
--------------------------
Patching file mozilla/xpcom/reflect/xptcall/src/md/unix/xptcinvoke_netbsd_m68k.cpp using Plan A...
Hunk #1 succeeded at 100.
Hunk #2 succeeded at 116.
done
=> Verifying /usr/pkgsrc/www/seamonkey/patches/patch-xf
=> Applying pkgsrc patch /usr/pkgsrc/www/seamonkey/patches/patch-xf
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-xf,v 1.7 2013/01/07 21:55:30 ryoon Exp $
|
|NetBSD/m68k xptcall support code. From pkgsrc/www/firefox/patch-ae.
|
|--- mozilla/xpcom/reflect/xptcall/src/md/unix/xptcstubs_netbsd_m68k.cpp.orig	2012-08-27 04:49:34.000000000 +0000
|+++ mozilla/xpcom/reflect/xptcall/src/md/unix/xptcstubs_netbsd_m68k.cpp
--------------------------
Patching file mozilla/xpcom/reflect/xptcall/src/md/unix/xptcstubs_netbsd_m68k.cpp using Plan A...
Hunk #1 succeeded at 91.
done
=> Verifying /usr/pkgsrc/www/seamonkey/patches/patch-xg
=> Applying pkgsrc patch /usr/pkgsrc/www/seamonkey/patches/patch-xg
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-xg,v 1.8 2013/01/07 21:55:30 ryoon Exp $
|
|NetBSD/arm xptcall support code. From pkgsrc/www/firefox/patch-bm.
|
|--- mozilla/xpcom/reflect/xptcall/src/md/unix/xptcstubs_arm_netbsd.cpp.orig	2012-08-27 04:49:34.000000000 +0000
|+++ mozilla/xpcom/reflect/xptcall/src/md/unix/xptcstubs_arm_netbsd.cpp
--------------------------
Patching file mozilla/xpcom/reflect/xptcall/src/md/unix/xptcstubs_arm_netbsd.cpp using Plan A...
Hunk #1 succeeded at 86.
done
=> Verifying /usr/pkgsrc/www/seamonkey/patches/patch-xj
=> Applying pkgsrc patch /usr/pkgsrc/www/seamonkey/patches/patch-xj
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-xj,v 1.7 2013/01/07 21:55:30 ryoon Exp $
|
|NetBSD ppc xptcall support code. Originally from pkgsrc/www/mozilla.
|
|--- mozilla/xpcom/reflect/xptcall/src/md/unix/xptcstubs_ppc_netbsd.cpp.orig	2012-11-18 10:19:54.000000000 +0000
|+++ mozilla/xpcom/reflect/xptcall/src/md/unix/xptcstubs_ppc_netbsd.cpp
--------------------------
Patching file mozilla/xpcom/reflect/xptcall/src/md/unix/xptcstubs_ppc_netbsd.cpp using Plan A...
Hunk #1 succeeded at 6.
Hunk #2 succeeded at 37.
Hunk #3 succeeded at 44.
Hunk #4 succeeded at 80.
Hunk #5 succeeded at 93.
Hunk #6 succeeded at 144.
Hunk #7 succeeded at 160.
Hunk #8 succeeded at 173.
done
=> Verifying /usr/pkgsrc/www/seamonkey/patches/patch-xk
=> Applying pkgsrc patch /usr/pkgsrc/www/seamonkey/patches/patch-xk
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-xk,v 1.7 2013/01/07 21:55:30 ryoon Exp $
|
|NetBSD ppc xptcall support code. Originally from pkgsrc/www/mozilla.
|
|--- mozilla/xpcom/reflect/xptcall/src/md/unix/xptcstubs_asm_ppc_netbsd.s.orig	2012-11-18 10:19:54.000000000 +0000
|+++ mozilla/xpcom/reflect/xptcall/src/md/unix/xptcstubs_asm_ppc_netbsd.s
--------------------------
Patching file mozilla/xpcom/reflect/xptcall/src/md/unix/xptcstubs_asm_ppc_netbsd.s using Plan A...
Hunk #1 succeeded at 25.
Hunk #2 succeeded at 50.
done
=> Verifying /usr/pkgsrc/www/seamonkey/patches/patch-xl
=> Applying pkgsrc patch /usr/pkgsrc/www/seamonkey/patches/patch-xl
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-xl,v 1.7 2013/01/07 21:55:30 ryoon Exp $
|
|NetBSD ppc xptcall support code. Originally from pkgsrc/www/mozilla.
|
|--- mozilla/xpcom/reflect/xptcall/src/md/unix/xptcinvoke_asm_ppc_netbsd.s.orig	2012-11-18 10:19:54.000000000 +0000
|+++ mozilla/xpcom/reflect/xptcall/src/md/unix/xptcinvoke_asm_ppc_netbsd.s
--------------------------
Patching file mozilla/xpcom/reflect/xptcall/src/md/unix/xptcinvoke_asm_ppc_netbsd.s using Plan A...
Hunk #1 succeeded at 20.
done
=> Verifying /usr/pkgsrc/www/seamonkey/patches/patch-xn
=> Applying pkgsrc patch /usr/pkgsrc/www/seamonkey/patches/patch-xn
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-xn,v 1.7 2013/01/07 21:55:30 ryoon Exp $
|
|--- mozilla/xpcom/reflect/xptcall/src/md/unix/xptcinvoke_asm_mips.s.orig	2012-08-27 04:49:34.000000000 +0000
|+++ mozilla/xpcom/reflect/xptcall/src/md/unix/xptcinvoke_asm_mips.s
--------------------------
Patching file mozilla/xpcom/reflect/xptcall/src/md/unix/xptcinvoke_asm_mips.s using Plan A...
Hunk #1 succeeded at 16.
done
=> Verifying /usr/pkgsrc/www/seamonkey/patches/patch-xo
=> Applying pkgsrc patch /usr/pkgsrc/www/seamonkey/patches/patch-xo
Hmm...  Looks like a unified diff to me...
The text leading up to this was:
--------------------------
|$NetBSD: patch-xo,v 1.7 2013/01/07 21:55:30 ryoon Exp $
|
|--- mozilla/xpcom/reflect/xptcall/src/md/unix/xptcstubs_asm_mips.s.orig	2012-08-27 04:49:34.000000000 +0000
|+++ mozilla/xpcom/reflect/xptcall/src/md/unix/xptcstubs_asm_mips.s
--------------------------
Patching file mozilla/xpcom/reflect/xptcall/src/md/unix/xptcstubs_asm_mips.s using Plan A...
Hunk #1 succeeded at 14.
done
===> Creating toolchain wrappers for seamonkey-2.18beta4
src=/usr/pkg/lib/pkgconfig/fixesproto.pc  dst=/tmp/pkgsrc/www/seamonkey/work/.buildlink/lib/pkgconfig/fixesext.pc;  /bin/mkdir -p /tmp/pkgsrc/www/seamonkey/work/.buildlink/lib/pkgconfig;  if test -f ${src}; then  /bin/ln -sf ${src} ${dst};  fi
src=/usr/pkg/lib/pkgconfig/compositeproto.pc  dst=/tmp/pkgsrc/www/seamonkey/work/.buildlink/lib/pkgconfig/compositeext.pc;  /bin/mkdir -p /tmp/pkgsrc/www/seamonkey/work/.buildlink/lib/pkgconfig;  if test -f ${src}; then  /bin/ln -sf ${src} ${dst};  fi
===> Configuring for seamonkey-2.18beta4
printf '#!/bin/sh\n[ "$*" = "-f" ] && exit 0\nexec /bin/rm $@\n' >  /tmp/pkgsrc/www/seamonkey/work/.wrapper/bin/rm
chmod +x /tmp/pkgsrc/www/seamonkey/work/.wrapper/bin/rm
=> Fixing absolute paths.
INFO: [subst.mk:fix-paths] Nothing changed in ./mozilla/xpcom/build/nsXPCOMPrivate.h.
=> Fixing path to python.
WARNING: [subst.mk:python] Ignoring non-existent file "./media/webrtc/trunk/build/common.gypi".
cd /tmp/pkgsrc/www/seamonkey/work/comm-beta && /usr/bin/env PTHREAD_CFLAGS=\ -pthread\  PTHREAD_LDFLAGS=\ -pthread PTHREAD_LIBS=-lpthread\ -lrt PTHREADBASE=/usr DL_CFLAGS= DL_LDFLAGS= DL_LIBS= PYTHON=/usr/pkg/bin/python2.7 ac_cv_sqlite_secure_delete=yes FREETYPE_CONFIG=/usr/pkg/bin/freetype-config INSTALL_INFO= MAKEINFO=/tmp/pkgsrc/www/seamonkey/work/.tools/bin/makeinfo FLEX= BISON= AWK=/usr/bin/awk CAT=/bin/cat ac_cv_path_CAT=/bin/cat CHMOD=/bin/chmod CMP=/usr/bin/cmp CP=/bin/cp DIFF=/usr/bin/diff ECHO=echo ac_cv_path_ECHO=echo EGREP=/bin/egrep ac_cv_path_EGREP=/bin/egrep SETENV=/usr/bin/env ENV_PROG=/usr/bin/env ac_cv_path_ENV=/usr/bin/env FALSE=false ac_cv_path_FALSE=false FIND=/usr/bin/find GREP=/bin/grep ac_cv_path_GREP=/bin/grep HOSTNAME=/bin/hostname LN=/bin/ln LS=/bin/ls MKDIR=/bin/mkdir\ -p MV=/bin/mv PERL=/usr/pkg/bin/perl PERL_PATH=/usr/pkg/bin/perl RM=/bin/rm RMDIR=/bin/rmdir SED=/bin/sed SORT=/usr/bin/sort TAR=/bin/tar TEST=test ac_cv_path_TEST=test TOUCH=/usr/bin/touch TR=/usr/bin/tr TRUE=true ac_cv_path_TRUE=true PKG_CONFIG=/tmp/pkgsrc/www/seamonkey/work/.tools/bin/pkg-config PKG_CONFIG_LIBDIR=/tmp/pkgsrc/www/seamonkey/work/.buildlink/lib/pkgconfig:/tmp/pkgsrc/www/seamonkey/work/.buildlink/share/pkgconfig PKG_CONFIG_LOG=/tmp/pkgsrc/www/seamonkey/work/.pkg-config.log PKG_CONFIG_PATH= MAKE=make WRAPPER_DEBUG=no WRAPPER_UPDATE_CACHE=yes MOZILLA_PKG_NAME=seamonkey PYTHON=/usr/pkg/bin/python2.7 CC=gcc CFLAGS=-O3\ -pipe\ -fstack-protector\ -Wno-error\ -I/usr/include\ -I/usr/pkg/include\ -I/usr/pkg/include/nspr\ -I/usr/pkg/include/libdrm\ -I/usr/pkg/include/freetype2 CPPFLAGS=-I/usr/include\ -I/usr/pkg/include\ -I/usr/pkg/include/nspr\ -I/usr/pkg/include/libdrm\ -I/usr/pkg/include/freetype2 CXX=g++ CXXFLAGS=-O3\ -pipe\ -fstack-protector\ -Wno-error\ -I/usr/include\ -I/usr/pkg/include\ -I/usr/pkg/include/nspr\ -I/usr/pkg/include/libdrm\ -I/usr/pkg/include/freetype2 COMPILER_RPATH_FLAG=-Wl,-R F77=f77 FC=f77 FFLAGS=-O LANG=C LC_ALL=C LC_COLLATE=C LC_CTYPE=C LC_MESSAGES=C LC_MONETARY=C LC_NUMERIC=C LC_TIME=C LDFLAGS=-Wl,-R/usr/pkg/lib/seamonkey\ -L/usr/lib64\ -Wl,-R/usr/lib64\ -L/usr/pkg/lib\ -Wl,-R/usr/pkg/lib\ -L/usr/pkg/lib/nspr\ -Wl,-R/usr/pkg/lib/nspr\ -L/usr/pkg/lib/nss\ -Wl,-R/usr/pkg/lib/nss LINKER_RPATH_FLAG=-R PATH=/tmp/pkgsrc/www/seamonkey/work/.wrapper/bin:/tmp/pkgsrc/www/seamonkey/work/.buildlink/bin:/tmp/pkgsrc/www/seamonkey/work/.tools/bin:/tmp/pkgsrc/www/seamonkey/work/.gcc/bin:/usr/pkg/bin:/bin:/usr/bin:/usr/pkg/bin:/usr/pkg/bin PREFIX=/usr/pkg PKG_SYSCONFDIR=/usr/pkg/etc HOME=/tmp/pkgsrc/www/seamonkey/work/.home CONFIG_SHELL=/bin/sh LIBS= ac_given_INSTALL=/usr/bin/install\ -c\ -o\ pbulk\ -g\ pbulk autoconf
cd /tmp/pkgsrc/www/seamonkey/work/comm-beta/mozilla && /usr/bin/env PTHREAD_CFLAGS=\ -pthread\  PTHREAD_LDFLAGS=\ -pthread PTHREAD_LIBS=-lpthread\ -lrt PTHREADBASE=/usr DL_CFLAGS= DL_LDFLAGS= DL_LIBS= PYTHON=/usr/pkg/bin/python2.7 ac_cv_sqlite_secure_delete=yes FREETYPE_CONFIG=/usr/pkg/bin/freetype-config INSTALL_INFO= MAKEINFO=/tmp/pkgsrc/www/seamonkey/work/.tools/bin/makeinfo FLEX= BISON= AWK=/usr/bin/awk CAT=/bin/cat ac_cv_path_CAT=/bin/cat CHMOD=/bin/chmod CMP=/usr/bin/cmp CP=/bin/cp DIFF=/usr/bin/diff ECHO=echo ac_cv_path_ECHO=echo EGREP=/bin/egrep ac_cv_path_EGREP=/bin/egrep SETENV=/usr/bin/env ENV_PROG=/usr/bin/env ac_cv_path_ENV=/usr/bin/env FALSE=false ac_cv_path_FALSE=false FIND=/usr/bin/find GREP=/bin/grep ac_cv_path_GREP=/bin/grep HOSTNAME=/bin/hostname LN=/bin/ln LS=/bin/ls MKDIR=/bin/mkdir\ -p MV=/bin/mv PERL=/usr/pkg/bin/perl PERL_PATH=/usr/pkg/bin/perl RM=/bin/rm RMDIR=/bin/rmdir SED=/bin/sed SORT=/usr/bin/sort TAR=/bin/tar TEST=test ac_cv_path_TEST=test TOUCH=/usr/bin/touch TR=/usr/bin/tr TRUE=true ac_cv_path_TRUE=true PKG_CONFIG=/tmp/pkgsrc/www/seamonkey/work/.tools/bin/pkg-config PKG_CONFIG_LIBDIR=/tmp/pkgsrc/www/seamonkey/work/.buildlink/lib/pkgconfig:/tmp/pkgsrc/www/seamonkey/work/.buildlink/share/pkgconfig PKG_CONFIG_LOG=/tmp/pkgsrc/www/seamonkey/work/.pkg-config.log PKG_CONFIG_PATH= MAKE=make WRAPPER_DEBUG=no WRAPPER_UPDATE_CACHE=yes MOZILLA_PKG_NAME=seamonkey PYTHON=/usr/pkg/bin/python2.7 CC=gcc CFLAGS=-O3\ -pipe\ -fstack-protector\ -Wno-error\ -I/usr/include\ -I/usr/pkg/include\ -I/usr/pkg/include/nspr\ -I/usr/pkg/include/libdrm\ -I/usr/pkg/include/freetype2 CPPFLAGS=-I/usr/include\ -I/usr/pkg/include\ -I/usr/pkg/include/nspr\ -I/usr/pkg/include/libdrm\ -I/usr/pkg/include/freetype2 CXX=g++ CXXFLAGS=-O3\ -pipe\ -fstack-protector\ -Wno-error\ -I/usr/include\ -I/usr/pkg/include\ -I/usr/pkg/include/nspr\ -I/usr/pkg/include/libdrm\ -I/usr/pkg/include/freetype2 COMPILER_RPATH_FLAG=-Wl,-R F77=f77 FC=f77 FFLAGS=-O LANG=C LC_ALL=C LC_COLLATE=C LC_CTYPE=C LC_MESSAGES=C LC_MONETARY=C LC_NUMERIC=C LC_TIME=C LDFLAGS=-Wl,-R/usr/pkg/lib/seamonkey\ -L/usr/lib64\ -Wl,-R/usr/lib64\ -L/usr/pkg/lib\ -Wl,-R/usr/pkg/lib\ -L/usr/pkg/lib/nspr\ -Wl,-R/usr/pkg/lib/nspr\ -L/usr/pkg/lib/nss\ -Wl,-R/usr/pkg/lib/nss LINKER_RPATH_FLAG=-R PATH=/tmp/pkgsrc/www/seamonkey/work/.wrapper/bin:/tmp/pkgsrc/www/seamonkey/work/.buildlink/bin:/tmp/pkgsrc/www/seamonkey/work/.tools/bin:/tmp/pkgsrc/www/seamonkey/work/.gcc/bin:/usr/pkg/bin:/bin:/usr/bin:/usr/pkg/bin:/usr/pkg/bin PREFIX=/usr/pkg PKG_SYSCONFDIR=/usr/pkg/etc HOME=/tmp/pkgsrc/www/seamonkey/work/.home CONFIG_SHELL=/bin/sh LIBS= ac_given_INSTALL=/usr/bin/install\ -c\ -o\ pbulk\ -g\ pbulk autoconf
cd /tmp/pkgsrc/www/seamonkey/work/comm-beta/mozilla/js/src && /usr/bin/env PTHREAD_CFLAGS=\ -pthread\  PTHREAD_LDFLAGS=\ -pthread PTHREAD_LIBS=-lpthread\ -lrt PTHREADBASE=/usr DL_CFLAGS= DL_LDFLAGS= DL_LIBS= PYTHON=/usr/pkg/bin/python2.7 ac_cv_sqlite_secure_delete=yes FREETYPE_CONFIG=/usr/pkg/bin/freetype-config INSTALL_INFO= MAKEINFO=/tmp/pkgsrc/www/seamonkey/work/.tools/bin/makeinfo FLEX= BISON= AWK=/usr/bin/awk CAT=/bin/cat ac_cv_path_CAT=/bin/cat CHMOD=/bin/chmod CMP=/usr/bin/cmp CP=/bin/cp DIFF=/usr/bin/diff ECHO=echo ac_cv_path_ECHO=echo EGREP=/bin/egrep ac_cv_path_EGREP=/bin/egrep SETENV=/usr/bin/env ENV_PROG=/usr/bin/env ac_cv_path_ENV=/usr/bin/env FALSE=false ac_cv_path_FALSE=false FIND=/usr/bin/find GREP=/bin/grep ac_cv_path_GREP=/bin/grep HOSTNAME=/bin/hostname LN=/bin/ln LS=/bin/ls MKDIR=/bin/mkdir\ -p MV=/bin/mv PERL=/usr/pkg/bin/perl PERL_PATH=/usr/pkg/bin/perl RM=/bin/rm RMDIR=/bin/rmdir SED=/bin/sed SORT=/usr/bin/sort TAR=/bin/tar TEST=test ac_cv_path_TEST=test TOUCH=/usr/bin/touch TR=/usr/bin/tr TRUE=true ac_cv_path_TRUE=true PKG_CONFIG=/tmp/pkgsrc/www/seamonkey/work/.tools/bin/pkg-config PKG_CONFIG_LIBDIR=/tmp/pkgsrc/www/seamonkey/work/.buildlink/lib/pkgconfig:/tmp/pkgsrc/www/seamonkey/work/.buildlink/share/pkgconfig PKG_CONFIG_LOG=/tmp/pkgsrc/www/seamonkey/work/.pkg-config.log PKG_CONFIG_PATH= MAKE=make WRAPPER_DEBUG=no WRAPPER_UPDATE_CACHE=yes MOZILLA_PKG_NAME=seamonkey PYTHON=/usr/pkg/bin/python2.7 CC=gcc CFLAGS=-O3\ -pipe\ -fstack-protector\ -Wno-error\ -I/usr/include\ -I/usr/pkg/include\ -I/usr/pkg/include/nspr\ -I/usr/pkg/include/libdrm\ -I/usr/pkg/include/freetype2 CPPFLAGS=-I/usr/include\ -I/usr/pkg/include\ -I/usr/pkg/include/nspr\ -I/usr/pkg/include/libdrm\ -I/usr/pkg/include/freetype2 CXX=g++ CXXFLAGS=-O3\ -pipe\ -fstack-protector\ -Wno-error\ -I/usr/include\ -I/usr/pkg/include\ -I/usr/pkg/include/nspr\ -I/usr/pkg/include/libdrm\ -I/usr/pkg/include/freetype2 COMPILER_RPATH_FLAG=-Wl,-R F77=f77 FC=f77 FFLAGS=-O LANG=C LC_ALL=C LC_COLLATE=C LC_CTYPE=C LC_MESSAGES=C LC_MONETARY=C LC_NUMERIC=C LC_TIME=C LDFLAGS=-Wl,-R/usr/pkg/lib/seamonkey\ -L/usr/lib64\ -Wl,-R/usr/lib64\ -L/usr/pkg/lib\ -Wl,-R/usr/pkg/lib\ -L/usr/pkg/lib/nspr\ -Wl,-R/usr/pkg/lib/nspr\ -L/usr/pkg/lib/nss\ -Wl,-R/usr/pkg/lib/nss LINKER_RPATH_FLAG=-R PATH=/tmp/pkgsrc/www/seamonkey/work/.wrapper/bin:/tmp/pkgsrc/www/seamonkey/work/.buildlink/bin:/tmp/pkgsrc/www/seamonkey/work/.tools/bin:/tmp/pkgsrc/www/seamonkey/work/.gcc/bin:/usr/pkg/bin:/bin:/usr/bin:/usr/pkg/bin:/usr/pkg/bin PREFIX=/usr/pkg PKG_SYSCONFDIR=/usr/pkg/etc HOME=/tmp/pkgsrc/www/seamonkey/work/.home CONFIG_SHELL=/bin/sh LIBS= ac_given_INSTALL=/usr/bin/install\ -c\ -o\ pbulk\ -g\ pbulk autoconf
cd /tmp/pkgsrc/www/seamonkey/work/comm-beta/mozilla/nsprpub && /usr/bin/env PTHREAD_CFLAGS=\ -pthread\  PTHREAD_LDFLAGS=\ -pthread PTHREAD_LIBS=-lpthread\ -lrt PTHREADBASE=/usr DL_CFLAGS= DL_LDFLAGS= DL_LIBS= PYTHON=/usr/pkg/bin/python2.7 ac_cv_sqlite_secure_delete=yes FREETYPE_CONFIG=/usr/pkg/bin/freetype-config INSTALL_INFO= MAKEINFO=/tmp/pkgsrc/www/seamonkey/work/.tools/bin/makeinfo FLEX= BISON= AWK=/usr/bin/awk CAT=/bin/cat ac_cv_path_CAT=/bin/cat CHMOD=/bin/chmod CMP=/usr/bin/cmp CP=/bin/cp DIFF=/usr/bin/diff ECHO=echo ac_cv_path_ECHO=echo EGREP=/bin/egrep ac_cv_path_EGREP=/bin/egrep SETENV=/usr/bin/env ENV_PROG=/usr/bin/env ac_cv_path_ENV=/usr/bin/env FALSE=false ac_cv_path_FALSE=false FIND=/usr/bin/find GREP=/bin/grep ac_cv_path_GREP=/bin/grep HOSTNAME=/bin/hostname LN=/bin/ln LS=/bin/ls MKDIR=/bin/mkdir\ -p MV=/bin/mv PERL=/usr/pkg/bin/perl PERL_PATH=/usr/pkg/bin/perl RM=/bin/rm RMDIR=/bin/rmdir SED=/bin/sed SORT=/usr/bin/sort TAR=/bin/tar TEST=test ac_cv_path_TEST=test TOUCH=/usr/bin/touch TR=/usr/bin/tr TRUE=true ac_cv_path_TRUE=true PKG_CONFIG=/tmp/pkgsrc/www/seamonkey/work/.tools/bin/pkg-config PKG_CONFIG_LIBDIR=/tmp/pkgsrc/www/seamonkey/work/.buildlink/lib/pkgconfig:/tmp/pkgsrc/www/seamonkey/work/.buildlink/share/pkgconfig PKG_CONFIG_LOG=/tmp/pkgsrc/www/seamonkey/work/.pkg-config.log PKG_CONFIG_PATH= MAKE=make WRAPPER_DEBUG=no WRAPPER_UPDATE_CACHE=yes MOZILLA_PKG_NAME=seamonkey PYTHON=/usr/pkg/bin/python2.7 CC=gcc CFLAGS=-O3\ -pipe\ -fstack-protector\ -Wno-error\ -I/usr/include\ -I/usr/pkg/include\ -I/usr/pkg/include/nspr\ -I/usr/pkg/include/libdrm\ -I/usr/pkg/include/freetype2 CPPFLAGS=-I/usr/include\ -I/usr/pkg/include\ -I/usr/pkg/include/nspr\ -I/usr/pkg/include/libdrm\ -I/usr/pkg/include/freetype2 CXX=g++ CXXFLAGS=-O3\ -pipe\ -fstack-protector\ -Wno-error\ -I/usr/include\ -I/usr/pkg/include\ -I/usr/pkg/include/nspr\ -I/usr/pkg/include/libdrm\ -I/usr/pkg/include/freetype2 COMPILER_RPATH_FLAG=-Wl,-R F77=f77 FC=f77 FFLAGS=-O LANG=C LC_ALL=C LC_COLLATE=C LC_CTYPE=C LC_MESSAGES=C LC_MONETARY=C LC_NUMERIC=C LC_TIME=C LDFLAGS=-Wl,-R/usr/pkg/lib/seamonkey\ -L/usr/lib64\ -Wl,-R/usr/lib64\ -L/usr/pkg/lib\ -Wl,-R/usr/pkg/lib\ -L/usr/pkg/lib/nspr\ -Wl,-R/usr/pkg/lib/nspr\ -L/usr/pkg/lib/nss\ -Wl,-R/usr/pkg/lib/nss LINKER_RPATH_FLAG=-R PATH=/tmp/pkgsrc/www/seamonkey/work/.wrapper/bin:/tmp/pkgsrc/www/seamonkey/work/.buildlink/bin:/tmp/pkgsrc/www/seamonkey/work/.tools/bin:/tmp/pkgsrc/www/seamonkey/work/.gcc/bin:/usr/pkg/bin:/bin:/usr/bin:/usr/pkg/bin:/usr/pkg/bin PREFIX=/usr/pkg PKG_SYSCONFDIR=/usr/pkg/etc HOME=/tmp/pkgsrc/www/seamonkey/work/.home CONFIG_SHELL=/bin/sh LIBS= ac_given_INSTALL=/usr/bin/install\ -c\ -o\ pbulk\ -g\ pbulk autoconf
cd /tmp/pkgsrc/www/seamonkey/work/comm-beta/ldap/sdks/c-sdk && /usr/bin/env PTHREAD_CFLAGS=\ -pthread\  PTHREAD_LDFLAGS=\ -pthread PTHREAD_LIBS=-lpthread\ -lrt PTHREADBASE=/usr DL_CFLAGS= DL_LDFLAGS= DL_LIBS= PYTHON=/usr/pkg/bin/python2.7 ac_cv_sqlite_secure_delete=yes FREETYPE_CONFIG=/usr/pkg/bin/freetype-config INSTALL_INFO= MAKEINFO=/tmp/pkgsrc/www/seamonkey/work/.tools/bin/makeinfo FLEX= BISON= AWK=/usr/bin/awk CAT=/bin/cat ac_cv_path_CAT=/bin/cat CHMOD=/bin/chmod CMP=/usr/bin/cmp CP=/bin/cp DIFF=/usr/bin/diff ECHO=echo ac_cv_path_ECHO=echo EGREP=/bin/egrep ac_cv_path_EGREP=/bin/egrep SETENV=/usr/bin/env ENV_PROG=/usr/bin/env ac_cv_path_ENV=/usr/bin/env FALSE=false ac_cv_path_FALSE=false FIND=/usr/bin/find GREP=/bin/grep ac_cv_path_GREP=/bin/grep HOSTNAME=/bin/hostname LN=/bin/ln LS=/bin/ls MKDIR=/bin/mkdir\ -p MV=/bin/mv PERL=/usr/pkg/bin/perl PERL_PATH=/usr/pkg/bin/perl RM=/bin/rm RMDIR=/bin/rmdir SED=/bin/sed SORT=/usr/bin/sort TAR=/bin/tar TEST=test ac_cv_path_TEST=test TOUCH=/usr/bin/touch TR=/usr/bin/tr TRUE=true ac_cv_path_TRUE=true PKG_CONFIG=/tmp/pkgsrc/www/seamonkey/work/.tools/bin/pkg-config PKG_CONFIG_LIBDIR=/tmp/pkgsrc/www/seamonkey/work/.buildlink/lib/pkgconfig:/tmp/pkgsrc/www/seamonkey/work/.buildlink/share/pkgconfig PKG_CONFIG_LOG=/tmp/pkgsrc/www/seamonkey/work/.pkg-config.log PKG_CONFIG_PATH= MAKE=make WRAPPER_DEBUG=no WRAPPER_UPDATE_CACHE=yes MOZILLA_PKG_NAME=seamonkey PYTHON=/usr/pkg/bin/python2.7 CC=gcc CFLAGS=-O3\ -pipe\ -fstack-protector\ -Wno-error\ -I/usr/include\ -I/usr/pkg/include\ -I/usr/pkg/include/nspr\ -I/usr/pkg/include/libdrm\ -I/usr/pkg/include/freetype2 CPPFLAGS=-I/usr/include\ -I/usr/pkg/include\ -I/usr/pkg/include/nspr\ -I/usr/pkg/include/libdrm\ -I/usr/pkg/include/freetype2 CXX=g++ CXXFLAGS=-O3\ -pipe\ -fstack-protector\ -Wno-error\ -I/usr/include\ -I/usr/pkg/include\ -I/usr/pkg/include/nspr\ -I/usr/pkg/include/libdrm\ -I/usr/pkg/include/freetype2 COMPILER_RPATH_FLAG=-Wl,-R F77=f77 FC=f77 FFLAGS=-O LANG=C LC_ALL=C LC_COLLATE=C LC_CTYPE=C LC_MESSAGES=C LC_MONETARY=C LC_NUMERIC=C LC_TIME=C LDFLAGS=-Wl,-R/usr/pkg/lib/seamonkey\ -L/usr/lib64\ -Wl,-R/usr/lib64\ -L/usr/pkg/lib\ -Wl,-R/usr/pkg/lib\ -L/usr/pkg/lib/nspr\ -Wl,-R/usr/pkg/lib/nspr\ -L/usr/pkg/lib/nss\ -Wl,-R/usr/pkg/lib/nss LINKER_RPATH_FLAG=-R PATH=/tmp/pkgsrc/www/seamonkey/work/.wrapper/bin:/tmp/pkgsrc/www/seamonkey/work/.buildlink/bin:/tmp/pkgsrc/www/seamonkey/work/.tools/bin:/tmp/pkgsrc/www/seamonkey/work/.gcc/bin:/usr/pkg/bin:/bin:/usr/bin:/usr/pkg/bin:/usr/pkg/bin PREFIX=/usr/pkg PKG_SYSCONFDIR=/usr/pkg/etc HOME=/tmp/pkgsrc/www/seamonkey/work/.home CONFIG_SHELL=/bin/sh LIBS= ac_given_INSTALL=/usr/bin/install\ -c\ -o\ pbulk\ -g\ pbulk autoconf
configure.in:668: AC_PROG_CPP was called before AC_PROG_CC
mkdir /tmp/pkgsrc/www/seamonkey/work/comm-beta/mozilla/js/src/.deps
=> Modifying GNU configure scripts to avoid --recheck
=> Replacing config-guess with pkgsrc versions
=> Replacing config-sub with pkgsrc versions
=> Replacing install-sh with pkgsrc version
=> Checking for portability problems in extracted files
creating cache ./config.cache
checking host system type... x86_64-unknown-linux-gnu
checking target system type... x86_64-unknown-linux-gnu
checking build system type... x86_64-unknown-linux-gnu
checking for mawk... /usr/bin/awk
checking for /usr/pkg/bin/python2.7... /usr/pkg/bin/python2.7
Creating Python environment
New python executable in /tmp/pkgsrc/www/seamonkey/work/comm-beta/_virtualenv/bin/python2.7
Also creating executable in /tmp/pkgsrc/www/seamonkey/work/comm-beta/_virtualenv/bin/python
Installing setuptools............done.
Installing pip...............done.
running build_ext
building '_psutil_linux' extension
creating build
creating build/temp.linux-x86_64-2.7
creating build/temp.linux-x86_64-2.7/psutil
gcc -pthread -fno-strict-aliasing -O3 -pipe -fstack-protector -Wno-error -DHAVE_DB_185_H -I/usr/include -I/usr/pkg/include/db4 -I/usr/pkg/include -I/usr/pkg/include/ncurses -DNDEBUG -O3 -pipe -fstack-protector -Wno-error -DHAVE_DB_185_H -I/usr/include -I/usr/pkg/include/db4 -I/usr/pkg/include -I/usr/pkg/include/ncurses -I/usr/include -I/usr/pkg/include -I/usr/pkg/include/nspr -I/usr/pkg/include/libdrm -I/usr/pkg/include/freetype2 -fPIC -I/usr/pkg/include/python2.7 -c psutil/_psutil_linux.c -o build/temp.linux-x86_64-2.7/psutil/_psutil_linux.o
creating build/lib.linux-x86_64-2.7
gcc -pthread -shared -L/tmp/pkgsrc/lang/python27/work/Python-2.7.5 -L/usr/lib64 -Wl,-R/usr/lib64 -L/usr/pkg/lib -Wl,-R/usr/pkg/lib -I/usr/include -I/usr/pkg/include -I/usr/pkg/include/nspr -I/usr/pkg/include/libdrm -I/usr/pkg/include/freetype2 build/temp.linux-x86_64-2.7/psutil/_psutil_linux.o -L/usr/pkg/lib -lpython2.7 -o build/lib.linux-x86_64-2.7/_psutil_linux.so
building '_psutil_posix' extension
gcc -pthread -fno-strict-aliasing -O3 -pipe -fstack-protector -Wno-error -DHAVE_DB_185_H -I/usr/include -I/usr/pkg/include/db4 -I/usr/pkg/include -I/usr/pkg/include/ncurses -DNDEBUG -O3 -pipe -fstack-protector -Wno-error -DHAVE_DB_185_H -I/usr/include -I/usr/pkg/include/db4 -I/usr/pkg/include -I/usr/pkg/include/ncurses -I/usr/include -I/usr/pkg/include -I/usr/pkg/include/nspr -I/usr/pkg/include/libdrm -I/usr/pkg/include/freetype2 -fPIC -I/usr/pkg/include/python2.7 -c psutil/_psutil_posix.c -o build/temp.linux-x86_64-2.7/psutil/_psutil_posix.o
gcc -pthread -shared -L/tmp/pkgsrc/lang/python27/work/Python-2.7.5 -L/usr/lib64 -Wl,-R/usr/lib64 -L/usr/pkg/lib -Wl,-R/usr/pkg/lib -I/usr/include -I/usr/pkg/include -I/usr/pkg/include/nspr -I/usr/pkg/include/libdrm -I/usr/pkg/include/freetype2 build/temp.linux-x86_64-2.7/psutil/_psutil_posix.o -L/usr/pkg/lib -lpython2.7 -o build/lib.linux-x86_64-2.7/_psutil_posix.so
copying build/lib.linux-x86_64-2.7/_psutil_linux.so -> 
copying build/lib.linux-x86_64-2.7/_psutil_posix.so -> 

checking for /usr/pkg/bin/perl... /usr/pkg/bin/perl
defined(@array) is deprecated at ./mozilla/config/milestone.pl line 58.
	(Maybe you should just omit the defined()?)
checking for gcc... gcc
checking whether the C compiler (gcc -O3 -pipe -fstack-protector -Wno-error -I/usr/include -I/usr/pkg/include -I/usr/pkg/include/nspr -I/usr/pkg/include/libdrm -I/usr/pkg/include/freetype2 -Wl,-R/usr/pkg/lib/seamonkey -L/usr/lib64 -Wl,-R/usr/lib64 -L/usr/pkg/lib -Wl,-R/usr/pkg/lib -L/usr/pkg/lib/nspr -Wl,-R/usr/pkg/lib/nspr -L/usr/pkg/lib/nss -Wl,-R/usr/pkg/lib/nss) works... yes
checking whether the C compiler (gcc -O3 -pipe -fstack-protector -Wno-error -I/usr/include -I/usr/pkg/include -I/usr/pkg/include/nspr -I/usr/pkg/include/libdrm -I/usr/pkg/include/freetype2 -Wl,-R/usr/pkg/lib/seamonkey -L/usr/lib64 -Wl,-R/usr/lib64 -L/usr/pkg/lib -Wl,-R/usr/pkg/lib -L/usr/pkg/lib/nspr -Wl,-R/usr/pkg/lib/nspr -L/usr/pkg/lib/nss -Wl,-R/usr/pkg/lib/nss) is a cross-compiler... no
checking whether we are using GNU C... yes
checking whether gcc accepts -g... yes
checking for c++... g++
checking whether the C++ compiler (g++ -O3 -pipe -fstack-protector -Wno-error -I/usr/include -I/usr/pkg/include -I/usr/pkg/include/nspr -I/usr/pkg/include/libdrm -I/usr/pkg/include/freetype2 -Wl,-R/usr/pkg/lib/seamonkey -L/usr/lib64 -Wl,-R/usr/lib64 -L/usr/pkg/lib -Wl,-R/usr/pkg/lib -L/usr/pkg/lib/nspr -Wl,-R/usr/pkg/lib/nspr -L/usr/pkg/lib/nss -Wl,-R/usr/pkg/lib/nss) works... yes
checking whether the C++ compiler (g++ -O3 -pipe -fstack-protector -Wno-error -I/usr/include -I/usr/pkg/include -I/usr/pkg/include/nspr -I/usr/pkg/include/libdrm -I/usr/pkg/include/freetype2 -Wl,-R/usr/pkg/lib/seamonkey -L/usr/lib64 -Wl,-R/usr/lib64 -L/usr/pkg/lib -Wl,-R/usr/pkg/lib -L/usr/pkg/lib/nspr -Wl,-R/usr/pkg/lib/nspr -L/usr/pkg/lib/nss -Wl,-R/usr/pkg/lib/nss) is a cross-compiler... no
checking whether we are using GNU C++... yes
checking whether g++ accepts -g... yes
checking for ranlib... ranlib
checking for as... /tmp/pkgsrc/www/seamonkey/work/.wrapper/bin/as
checking for ar... ar
checking for ld... ld
checking for strip... strip
checking for windres... no
checking whether gcc and cc understand -c and -o together... yes
checking how to run the C preprocessor... gcc -E
checking how to run the C++ preprocessor... g++ -E
checking for a BSD compatible install... /usr/bin/install -c -o pbulk -g pbulk
checking whether ln -s works... yes
checking for minimum required perl version >= 5.006... 5.016003
checking for full perl installation... yes
checking for doxygen... :
checking for autoconf... /tmp/pkgsrc/www/seamonkey/work/.tools/bin/autoconf
checking for unzip... /tmp/pkgsrc/www/seamonkey/work/.tools/bin/unzip
checking for zip... /tmp/pkgsrc/www/seamonkey/work/.tools/bin/zip
checking for xargs... /tmp/pkgsrc/www/seamonkey/work/.tools/bin/xargs
checking for X... libraries , headers 
checking for dnet_ntoa in -ldnet... no
checking for dnet_ntoa in -ldnet_stub... no
checking for gethostbyname... yes
checking for connect... yes
checking for remove... yes
checking for shmat... yes
checking for IceConnectionNumber in -lICE... yes
checking whether the C compiler supports -Werror=return-type... yes
checking whether the C compiler supports -Wtype-limits... yes
checking whether the C compiler supports -Wempty-body... yes
checking whether the C compiler supports -Wno-overlength-strings... yes
checking whether the C++ compiler supports -Werror=return-type... yes
checking whether the C++ compiler supports -Wtype-limits... yes
checking whether the C++ compiler supports -Wempty-body... yes
checking whether the C++ compiler supports -Werror=conversion-null... yes
checking whether the C++ compiler supports -Wno-overlength-strings... yes
checking whether the C++ compiler supports -Wno-invalid-offsetof... yes
checking whether the C++ compiler supports -Wno-variadic-macros... yes
checking whether ld has archive extraction flags... yes
checking that static assertion macros used in autoconf tests work... yes
checking for 64-bit OS... yes
checking for custom <stdint.h> implementation... none specified
checking whether the linker supports Identical Code Folding... no
checking whether removing dead symbols breaks debugging... /tmp/pkgsrc/www/seamonkey/work/comm-beta/_virtualenv/bin/python: can't open file '/tmp/pkgsrc/www/seamonkey/work/comm-beta/build/autoconf/check_debug_ranges.py': [Errno 2] No such file or directory
/tmp/pkgsrc/www/seamonkey/work/comm-beta/_virtualenv/bin/python: can't open file '/tmp/pkgsrc/www/seamonkey/work/comm-beta/build/autoconf/check_debug_ranges.py': [Errno 2] No such file or directory
no
checking for ANSI C header files... yes
checking for working const... yes
checking for mode_t... yes
checking for off_t... yes
checking for pid_t... yes
checking for size_t... yes
checking for __stdcall... no
checking for ssize_t... yes
checking for st_blksize in struct stat... yes
checking for siginfo_t... yes
checking for int64... no
checking for uint... yes
checking for uint_t... no
checking for uname.domainname... yes
checking for uname.__domainname... no
checking for gcc c++0x headers bug without rtti... no
checking for usable char16_t (2 bytes, unsigned)... yes
checking for usable wchar_t (2 bytes, unsigned)... no
checking for visibility(hidden) attribute... yes
checking for visibility(default) attribute... yes
checking for visibility pragma support... yes
checking For gcc visibility bug with class-level attributes (GCC bug 26905)... no
checking For x86_64 gcc visibility bug with builtins (GCC bug 20297)... no
checking for dirent.h that defines DIR... yes
checking for opendir in -ldir... no
checking for sys/byteorder.h... no
checking for compat.h... no
checking for getopt.h... yes
checking for sys/bitypes.h... yes
checking for memory.h... yes
checking for unistd.h... yes
checking for gnu/libc-version.h... yes
checking for nl_types.h... yes
checking for malloc.h... yes
checking for X11/XKBlib.h... yes
checking for sys/statvfs.h... yes
checking for sys/statfs.h... yes
checking for sys/vfs.h... yes
checking for sys/mount.h... yes
checking for new... yes
checking for sys/cdefs.h... yes
checking for gethostbyname_r in -lc_r... no
checking for atan in -lm... yes
checking for dlopen in -ldl... yes
checking for dlfcn.h... yes
checking for dladdr... yes
checking for socket in -lsocket... no
checking for XDrawLines in -lX11... yes
checking for XextAddDisplay in -lXext... yes
checking for XtFree in -lXt... yes
checking for pthread_create in -lpthreads... no
checking for pthread_create in -lpthread... yes
checking whether gcc accepts -pthread... yes
checking whether mmap() sees write()s... yes
checking whether gcc needs -traditional... no
checking for 8-bit clean memcmp... yes
checking for random... yes
checking for strerror... yes
checking for lchown... yes
checking for fchmod... yes
checking for snprintf... yes
checking for statvfs... yes
checking for memmove... yes
checking for rint... yes
checking for stat64... yes
checking for lstat64... yes
checking for truncate64... yes
checking for statvfs64... yes
checking for flockfile... yes
checking for getpagesize... yes
checking for localtime_r... yes
checking for strtok_r... yes
checking for wcrtomb... yes
checking for mbrtowc... yes
checking for res_ninit()... yes
checking for gnu_get_libc_version()... yes
checking for iconv in -lc... yes
checking for iconv()... yes
checking for iconv() with const input... no
checking for nl_langinfo and CODESET... yes
checking for an implementation of va_copy()... yes
checking for an implementation of __va_copy()... yes
checking whether va_lists can be copied by value... no
checking for gcc 3.0 ABI... yes
checking for C++ "explicit" keyword... yes
checking for C++ "typename" keyword... yes
checking for modern C++ template specialization syntax support... yes
checking whether partial template specialization works... yes
checking whether operators must be re-defined for templates derived from templates... no
checking whether we need to cast a derived template to pass as its base class... no
checking whether the compiler can resolve const ambiguities for templates... yes
checking whether the C++ "using" keyword can change access... yes
checking whether the C++ "using" keyword resolves ambiguity... yes
checking for "std::" namespace... yes
checking whether standard template operator!=() is ambiguous... unambiguous
checking for C++ reinterpret_cast... yes
checking for C++ dynamic_cast to void*... yes
checking whether C++ requires implementation of unused virtual methods... no
checking for trouble comparing to zero near std::operator!=()... no
checking for __thread keyword for TLS variables... yes
checking for malloc.h... (cached) yes
checking for strndup... yes
checking for posix_memalign... yes
checking for memalign... yes
checking for valloc... yes
checking for __attribute__((always_inline))... yes
checking for __attribute__((malloc))... yes
checking for __attribute__((warn_unused_result))... yes
checking for __attribute__((noreturn))... yes
checking for LC_MESSAGES... yes
checking for localeconv... yes
checking for nspr-config... /usr/pkg/bin/nspr-config
checking for NSPR - version >= 4.9.3... yes
checking for pkg-config... /tmp/pkgsrc/www/seamonkey/work/.tools/bin/pkg-config
checking for NSS - version >= 3.14... yes
checking for jpeg_destroy_compress in -ljpeg... no
checking for gzread in -lz... yes
checking for BZ2_bzread in -lbz2... yes
checking for hunspell... yes
checking MOZ_HUNSPELL_CFLAGS... -I/usr/pkg/include/hunspell 
checking MOZ_HUNSPELL_LIBS... -L/usr/pkg/lib -Wl,-R/usr/pkg/lib -lhunspell-1.3 
checking for application to build... suite
checking if app-specific confvars.sh exists... ./suite/confvars.sh
checking for gtk+-2.0 >= 2.10.0 gtk+-unix-print-2.0 glib-2.0 gobject-2.0 gdk-x11-2.0... yes
checking MOZ_GTK2_CFLAGS... -D_REENTRANT -pthread -I/usr/pkg/include/gtk-2.0 -I/usr/pkg/include/gtk-unix-print-2.0 -I/usr/pkg/include/gtk-2.0 -I/usr/pkg/include/atk-1.0 -I/usr/pkg/include/pango-1.0 -I/usr/pkg/include/harfbuzz -I/usr/pkg/include/gtk-2.0 -I/usr/pkg/lib/gtk-2.0/include -I/usr/pkg/include/pango-1.0 -I/usr/pkg/include/cairo -I/usr/pkg/include/pixman-1 -I/usr/pkg/include -I/usr/pkg/include/freetype2 -I/usr/pkg/include -I/usr/pkg/include/libpng16 -I/usr/pkg/include -I/usr/pkg/include/gdk-pixbuf-2.0 -I/usr/pkg/include/libpng16 -I/usr/pkg/include/glib/glib-2.0 -I/usr/pkg/lib/glib-2.0/include -I/usr/pkg/include 
checking MOZ_GTK2_LIBS... -L/usr/pkg/lib -Wl,-R/usr/pkg/lib -lgtk-x11-2.0 -Wl,-R/usr/pkg/lib -lgtk-x11-2.0 -Wl,-R/usr/pkg/lib -latk-1.0 -Wl,-R/usr/pkg/lib -lgio-2.0 -Wl,-R/usr/pkg/lib -lpangoft2-1.0 -Wl,-R/usr/pkg/lib -lfreetype -Wl,-R/usr/pkg/lib -lfontconfig -Wl,-R/usr/pkg/lib -lgdk-x11-2.0 -Wl,-R/usr/pkg/lib -lpangocairo-1.0 -Wl,-R/usr/pkg/lib -lpango-1.0 -Wl,-R/usr/pkg/lib -lcairo -Wl,-R/usr/pkg/lib -lgdk_pixbuf-2.0 -Wl,-R/usr/pkg/lib -lgobject-2.0 -Wl,-R/usr/pkg/lib -lglib-2.0 
checking for pango >= 1.14.0 pangoft2 >= 1.14.0... yes
checking MOZ_PANGO_CFLAGS... -pthread -I/usr/pkg/include/pango-1.0 -I/usr/pkg/include/harfbuzz -I/usr/pkg/include/pango-1.0 -I/usr/pkg/include/glib/glib-2.0 -I/usr/pkg/lib/glib-2.0/include -I/usr/pkg/include -I/usr/pkg/include/freetype2 -I/usr/pkg/include 
checking MOZ_PANGO_LIBS... -L/usr/pkg/lib -Wl,-R/usr/pkg/lib -lpangoft2-1.0 -Wl,-R/usr/pkg/lib -lpango-1.0 -Wl,-R/usr/pkg/lib -lgobject-2.0 -Wl,-R/usr/pkg/lib -lglib-2.0 -Wl,-R/usr/pkg/lib -lfreetype -Wl,-R/usr/pkg/lib -lfontconfig 
checking for gio-2.0 >= 2.0... yes
checking MOZ_GIO_CFLAGS... -pthread -I/usr/pkg/include/glib/glib-2.0 -I/usr/pkg/lib/glib-2.0/include -I/usr/pkg/include 
checking MOZ_GIO_LIBS... -L/usr/pkg/lib -Wl,-R/usr/pkg/lib -lgio-2.0 -Wl,-R/usr/pkg/lib -lgobject-2.0 -Wl,-R/usr/pkg/lib -lglib-2.0 
checking for gconf-2.0 >= 1.2.1 gobject-2.0 ... checking for alsa... yes
checking MOZ_ALSA_CFLAGS... -I/usr/pkg/include -I/usr/pkg/include/alsa 
checking MOZ_ALSA_LIBS... -L/usr/pkg/lib -Wl,-R/usr/pkg/lib -lasound 
checking for tar archiver... checking for gnutar... /bin/tar
/bin/tar
checking for wget... checking for wget... no

checking for sqlite3 >= 3.7.1... yes
checking SQLITE_CFLAGS... -I/usr/pkg/include 
checking SQLITE_LIBS... -L/usr/pkg/lib -Wl,-R/usr/pkg/lib -lsqlite3 
checking for valid optimization flags... yes
checking size of int *... 8
checking for __cxa_demangle... yes
checking for unwind.h... yes
checking for _Unwind_Backtrace... yes
checking for gcc -pipe support... yes
checking whether C compiler supports -fprofile-generate... yes
checking for correct temporary object destruction order... yes
checking for correct overload resolution with const and templates... no
checking what kind of list files are supported by the linker... linkerscript
checking what kind of ordering can be done with the linker... linkerscript
checking for glib-2.0 >= 1.3.7 gobject-2.0... yes
checking GLIB_CFLAGS... -I/usr/pkg/include/glib/glib-2.0 -I/usr/pkg/lib/glib-2.0/include -I/usr/pkg/include 
checking GLIB_LIBS... -L/usr/pkg/lib -Wl,-R/usr/pkg/lib -lgobject-2.0 -Wl,-R/usr/pkg/lib -lglib-2.0 
checking for stdint.h... yes
checking for inttypes.h... yes
checking for sys/int_types.h... no
checking for cairo >= 1.10 pixman-1 freetype2 fontconfig... yes
checking CAIRO_CFLAGS... -D_REENTRANT -I/usr/pkg/include/cairo -I/usr/pkg/include/libpng16 -I/usr/pkg/include -I/usr/pkg/include/pixman-1 -I/usr/pkg/include/freetype2 -I/usr/pkg/include 
checking CAIRO_LIBS... -L/usr/pkg/lib -Wl,-R/usr/pkg/lib -lcairo -Wl,-R/usr/pkg/lib -lpixman-1 -Wl,-R/usr/pkg/lib -lfreetype -Wl,-R/usr/pkg/lib -lfontconfig 
checking for cairo-xlib-xrender >= 1.10... yes
checking CAIRO_XRENDER_CFLAGS... -D_REENTRANT -I/usr/pkg/include/cairo -I/usr/pkg/include/pixman-1 -I/usr/pkg/include -I/usr/pkg/include/freetype2 -I/usr/pkg/include -I/usr/pkg/include/libpng16 -I/usr/pkg/include 
checking CAIRO_XRENDER_LIBS... -L/usr/pkg/lib -Wl,-R/usr/pkg/lib -lcairo -Wl,-R/usr/pkg/lib -lXext -Wl,-R/usr/pkg/lib -lXrender -Wl,-R/usr/pkg/lib -lX11 
updating cache ./config.cache
creating ./config.status
creating config files and headers...
configuring in mozilla
running /bin/sh ./configure  --enable-application=suite --disable-tests --disable-pedantic --enable-crypto --enable-optimize=-O2 --with-pthreads --disable-javaxpcom --enable-default-toolkit=cairo-gtk2 --enable-svg --enable-mathml --enable-system-cairo --enable-system-pixman --with-system-libvpx --enable-system-hunspell --enable-system-ffi --with-system-nss --with-system-nspr --with-system-jpeg --with-system-zlib --with-system-bz2 --with-system-libevent=/usr/pkg --enable-system-sqlite --disable-crashreporter --disable-libnotify --disable-necko-wifi --enable-chrome-format=flat --enable-libjpeg-turbo --disable-gnomevfs --disable-dbus --disable-gnomeui --enable-jemalloc --disable-debug --disable-debug-symbols --enable-install-strip --disable-calendar --prefix=/usr/pkg --build=x86_64-unknown-linux --host=x86_64-unknown-linux --mandir=/usr/pkg/share/man --enable-application=../suite --disable-official-branding --with-branding=../suite/branding/nightly --cache-file=.././config.cache --srcdir=.
loading cache .././config.cache
checking host system type... x86_64-unknown-linux-gnu
checking target system type... x86_64-unknown-linux-gnu
checking build system type... x86_64-unknown-linux-gnu
checking for mawk... (cached) /usr/bin/awk
Using Python from environment variable $PYTHON
Creating Python environment
Using real prefix '/usr/pkg'
New python executable in /tmp/pkgsrc/www/seamonkey/work/comm-beta/mozilla/_virtualenv/bin/python
Installing setuptools............done.
Installing pip...............done.
running build_ext
copying build/lib.linux-x86_64-2.7/_psutil_linux.so -> 
copying build/lib.linux-x86_64-2.7/_psutil_posix.so -> 

checking Python environment is Mozilla virtualenv... yes
checking for /usr/pkg/bin/perl... (cached) /usr/pkg/bin/perl
checking for objcopy... /usr/bin/objcopy
checking for gcc... (cached) gcc
checking whether the C compiler (gcc -O3 -pipe -fstack-protector -Wno-error -I/usr/include -I/usr/pkg/include -I/usr/pkg/include/nspr -I/usr/pkg/include/libdrm -I/usr/pkg/include/freetype2 -Wl,-R/usr/pkg/lib/seamonkey -L/usr/lib64 -Wl,-R/usr/lib64 -L/usr/pkg/lib -Wl,-R/usr/pkg/lib -L/usr/pkg/lib/nspr -Wl,-R/usr/pkg/lib/nspr -L/usr/pkg/lib/nss -Wl,-R/usr/pkg/lib/nss) works... yes
checking whether the C compiler (gcc -O3 -pipe -fstack-protector -Wno-error -I/usr/include -I/usr/pkg/include -I/usr/pkg/include/nspr -I/usr/pkg/include/libdrm -I/usr/pkg/include/freetype2 -Wl,-R/usr/pkg/lib/seamonkey -L/usr/lib64 -Wl,-R/usr/lib64 -L/usr/pkg/lib -Wl,-R/usr/pkg/lib -L/usr/pkg/lib/nspr -Wl,-R/usr/pkg/lib/nspr -L/usr/pkg/lib/nss -Wl,-R/usr/pkg/lib/nss) is a cross-compiler... no
checking whether we are using GNU C... (cached) yes
checking whether gcc accepts -g... (cached) yes
checking for c++... (cached) g++
checking whether the C++ compiler (g++ -O3 -pipe -fstack-protector -Wno-error -I/usr/include -I/usr/pkg/include -I/usr/pkg/include/nspr -I/usr/pkg/include/libdrm -I/usr/pkg/include/freetype2 -Wl,-R/usr/pkg/lib/seamonkey -L/usr/lib64 -Wl,-R/usr/lib64 -L/usr/pkg/lib -Wl,-R/usr/pkg/lib -L/usr/pkg/lib/nspr -Wl,-R/usr/pkg/lib/nspr -L/usr/pkg/lib/nss -Wl,-R/usr/pkg/lib/nss) works... yes
checking whether the C++ compiler (g++ -O3 -pipe -fstack-protector -Wno-error -I/usr/include -I/usr/pkg/include -I/usr/pkg/include/nspr -I/usr/pkg/include/libdrm -I/usr/pkg/include/freetype2 -Wl,-R/usr/pkg/lib/seamonkey -L/usr/lib64 -Wl,-R/usr/lib64 -L/usr/pkg/lib -Wl,-R/usr/pkg/lib -L/usr/pkg/lib/nspr -Wl,-R/usr/pkg/lib/nspr -L/usr/pkg/lib/nss -Wl,-R/usr/pkg/lib/nss) is a cross-compiler... no
checking whether we are using GNU C++... (cached) yes
checking whether g++ accepts -g... (cached) yes
checking for ranlib... (cached) ranlib
checking for as... (cached) /tmp/pkgsrc/www/seamonkey/work/.wrapper/bin/as
checking for ar... (cached) ar
checking for ld... (cached) ld
checking for strip... (cached) strip
checking for windres... no
checking how to run the C preprocessor... (cached) gcc -E
checking how to run the C++ preprocessor... (cached) g++ -E
checking for a BSD compatible install... /usr/bin/install -c -o pbulk -g pbulk
checking whether ln -s works... (cached) yes
checking for minimum required perl version >= 5.006... 5.016003
checking for full perl installation... yes
checking for doxygen... (cached) :
checking for autoconf... (cached) /tmp/pkgsrc/www/seamonkey/work/.tools/bin/autoconf
checking for unzip... (cached) /tmp/pkgsrc/www/seamonkey/work/.tools/bin/unzip
checking for zip... (cached) /tmp/pkgsrc/www/seamonkey/work/.tools/bin/zip
checking for xargs... (cached) /tmp/pkgsrc/www/seamonkey/work/.tools/bin/xargs
checking for rpmbuild... :
checking compiler version... gcc (GCC) 4.5.2
Copyright (C) 2010 Free Software Foundation, Inc.
This is free software; see the source for copying conditions.  There is NO
warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
checking for make... /tmp/pkgsrc/www/seamonkey/work/.tools/bin/make
checking for X... (cached) libraries , headers 
checking for dnet_ntoa in -ldnet... (cached) no
checking for dnet_ntoa in -ldnet_stub... (cached) no
checking for gethostbyname... (cached) yes
checking for connect... (cached) yes
checking for remove... (cached) yes
checking for shmat... (cached) yes
checking for IceConnectionNumber in -lICE... (cached) yes
checking that static assertion macros used in autoconf tests work... (cached) yes
checking for --noexecstack option to as... yes
checking for -z noexecstack option to ld... yes
checking for --build-id option to ld... yes
checking if toolchain supports -mssse3 option... yes
checking if toolchain supports -msse4.1 option... yes
checking whether the C compiler supports -Werror=return-type... yes
checking whether the C compiler supports -Wtype-limits... yes
checking whether the C compiler supports -Wempty-body... yes
checking whether the C++ compiler supports -Werror=return-type... yes
checking whether the C++ compiler supports -Wtype-limits... yes
checking whether the C++ compiler supports -Wempty-body... yes
checking whether the C++ compiler supports -Wno-invalid-offsetof... yes
checking whether ld has archive extraction flags... (cached) yes
checking for 64-bit OS... yes
checking for custom <stdint.h> implementation... none specified
defined(@array) is deprecated at ./config/milestone.pl line 58.
	(Maybe you should just omit the defined()?)
defined(@array) is deprecated at ./config/milestone.pl line 58.
	(Maybe you should just omit the defined()?)
checking whether the linker supports Identical Code Folding... no
checking whether removing dead symbols breaks debugging... no
checking for ANSI C header files... (cached) yes
checking for working const... (cached) yes
checking for mode_t... (cached) yes
checking for off_t... (cached) yes
checking for pid_t... (cached) yes
checking for size_t... (cached) yes
checking for __stdcall... (cached) no
checking for ssize_t... (cached) yes
checking for st_blksize in struct stat... (cached) yes
checking for siginfo_t... (cached) yes
checking for int64... (cached) no
checking for uint... (cached) yes
checking for uint_t... (cached) no
checking for uname.domainname... (cached) yes
checking for uname.__domainname... (cached) no
checking for gcc c++0x headers bug without rtti... (cached) no
checking for usable char16_t (2 bytes, unsigned)... (cached) yes
checking for usable wchar_t (2 bytes, unsigned)... (cached) no
checking for visibility(hidden) attribute... (cached) yes
checking for visibility(default) attribute... (cached) yes
checking for visibility pragma support... (cached) yes
checking For gcc visibility bug with class-level attributes (GCC bug 26905)... (cached) no
checking For x86_64 gcc visibility bug with builtins (GCC bug 20297)... (cached) no
checking for gcc PR49911... no
checking for gcc pr39608... no
checking for llvm pr8927... no
checking for __force_align_arg_pointer__ attribute... no
checking for dirent.h that defines DIR... (cached) yes
checking for opendir in -ldir... (cached) no
checking for sys/byteorder.h... (cached) no
checking for compat.h... (cached) no
checking for getopt.h... (cached) yes
checking for sys/bitypes.h... (cached) yes
checking for memory.h... (cached) yes
checking for unistd.h... (cached) yes
checking for gnu/libc-version.h... (cached) yes
checking for nl_types.h... (cached) yes
checking for malloc.h... (cached) yes
checking for X11/XKBlib.h... (cached) yes
checking for io.h... no
checking for cpuid.h... yes
checking for sys/statvfs.h... (cached) yes
checking for sys/statfs.h... (cached) yes
checking for sys/vfs.h... (cached) yes
checking for sys/mount.h... (cached) yes
checking for sys/quota.h... yes
checking for sys/sysmacros.h... yes
checking for linux/quota.h... yes
checking for linux/if_addr.h... yes
checking for linux/rtnetlink.h... yes
checking for sys/types.h... yes
checking for netinet/in.h... yes
checking for byteswap.h... yes
checking for sockaddr_in.sin_len... false
checking for sockaddr_in6.sin6_len... false
checking for sockaddr.sa_len... false
checking for new... (cached) yes
checking for sys/cdefs.h... (cached) yes
checking for linux/perf_event.h... yes
checking for perf_event_open system call... yes
checking for gethostbyname_r in -lc_r... (cached) no
checking for library containing dlopen... none required
checking for dlfcn.h... (cached) yes
checking for dladdr... (cached) yes
checking for memmem... yes
checking for socket in -lsocket... (cached) no
checking for XDrawLines in -lX11... (cached) yes
checking for XextAddDisplay in -lXext... (cached) yes
checking for XtFree in -lXt... (cached) yes
checking for XShmCreateImage in -lXext... yes
checking for X11/extensions/scrnsaver.h... no
checking for pthread_create in -lpthreads... no
checking for pthread_create in -lpthread... yes
checking whether gcc accepts -pthread... yes
checking whether gcc needs -traditional... (cached) no
checking for 8-bit clean memcmp... (cached) yes
checking for random... (cached) yes
checking for strerror... (cached) yes
checking for lchown... (cached) yes
checking for fchmod... (cached) yes
checking for snprintf... (cached) yes
checking for memmove... (cached) yes
checking for rint... (cached) yes
checking for stat64... (cached) yes
checking for lstat64... (cached) yes
checking for truncate64... (cached) yes
checking for setbuf... yes
checking for isatty... yes
checking for statvfs64... (cached) yes
checking for statvfs... (cached) yes
checking for statfs64... yes
checking for statfs... yes
checking for flockfile... (cached) yes
checking for getpagesize... (cached) yes
checking for localtime_r... (cached) yes
checking for strtok_r... (cached) yes
checking for clock_gettime(CLOCK_MONOTONIC)... -lrt
checking for wcrtomb... (cached) yes
checking for mbrtowc... (cached) yes
checking for res_ninit()... (cached) yes
checking for gnu_get_libc_version()... (cached) yes
checking for iconv in -lc... (cached) yes
checking for iconv()... (cached) yes
checking for iconv() with const input... (cached) no
checking for nl_langinfo and CODESET... (cached) yes
checking for an implementation of va_copy()... (cached) yes
checking for an implementation of __va_copy()... (cached) yes
checking whether va_lists can be copied by value... (cached) no
checking for modern C++ template specialization syntax support... (cached) yes
checking whether partial template specialization works... (cached) yes
checking whether the C++ "using" keyword resolves ambiguity... (cached) yes
checking for C++ dynamic_cast to void*... (cached) yes
checking whether C++ requires implementation of unused virtual methods... (cached) no
checking for trouble comparing to zero near std::operator!=()... (cached) no
checking for __thread keyword for TLS variables... (cached) yes
checking for malloc.h... (cached) yes
checking for strndup... (cached) yes
checking for posix_memalign... (cached) yes
checking for memalign... (cached) yes
checking for valloc... (cached) yes
checking for malloc_usable_size... yes
checking for __attribute__((always_inline))... (cached) yes
checking for __attribute__((malloc))... (cached) yes
checking for __attribute__((warn_unused_result))... (cached) yes
checking for LC_MESSAGES... (cached) yes
checking for localeconv... (cached) yes
checking for nspr-config... /usr/pkg/bin/nspr-config
checking for NSPR - version >= 4.9.6... yes
checking for event.h... yes
checking for event_init in -levent... yes
checking for pkg-config... /tmp/pkgsrc/www/seamonkey/work/.tools/bin/pkg-config
checking for NSS - version >= 3.14.3... yes
checking for YASM assembler... checking for yasm... yasm
checking for jpeg_destroy_compress in -ljpeg... (cached) no
checking for gzread in -lz... (cached) yes
checking for BZ2_bzread in -lbz2... (cached) yes
checking for hunspell... yes
checking MOZ_HUNSPELL_CFLAGS... -I/usr/pkg/include/hunspell 
checking MOZ_HUNSPELL_LIBS... -L/usr/pkg/lib -Wl,-R/usr/pkg/lib -lhunspell-1.3 
checking for libffi >= 3.0.9... yes
checking MOZ_FFI_CFLAGS... -I/usr/pkg/include 
checking MOZ_FFI_LIBS... -L/usr/pkg/lib -Wl,-R/usr/pkg/lib -lffi 
checking for application to build... ../suite
checking if app-specific confvars.sh exists... ./../suite/confvars.sh
checking for gtk+-2.0 >= 2.10.0 gtk+-unix-print-2.0 glib-2.0 gobject-2.0 gdk-x11-2.0... yes
checking MOZ_GTK2_CFLAGS... -D_REENTRANT -pthread -I/usr/pkg/include/gtk-2.0 -I/usr/pkg/include/gtk-unix-print-2.0 -I/usr/pkg/include/gtk-2.0 -I/usr/pkg/include/atk-1.0 -I/usr/pkg/include/pango-1.0 -I/usr/pkg/include/harfbuzz -I/usr/pkg/include/gtk-2.0 -I/usr/pkg/lib/gtk-2.0/include -I/usr/pkg/include/pango-1.0 -I/usr/pkg/include/cairo -I/usr/pkg/include/pixman-1 -I/usr/pkg/include -I/usr/pkg/include/freetype2 -I/usr/pkg/include -I/usr/pkg/include/libpng16 -I/usr/pkg/include -I/usr/pkg/include/gdk-pixbuf-2.0 -I/usr/pkg/include/libpng16 -I/usr/pkg/include/glib/glib-2.0 -I/usr/pkg/lib/glib-2.0/include -I/usr/pkg/include 
checking MOZ_GTK2_LIBS... -L/usr/pkg/lib -Wl,-R/usr/pkg/lib -lgtk-x11-2.0 -Wl,-R/usr/pkg/lib -lgtk-x11-2.0 -Wl,-R/usr/pkg/lib -latk-1.0 -Wl,-R/usr/pkg/lib -lgio-2.0 -Wl,-R/usr/pkg/lib -lpangoft2-1.0 -Wl,-R/usr/pkg/lib -lfreetype -Wl,-R/usr/pkg/lib -lfontconfig -Wl,-R/usr/pkg/lib -lgdk-x11-2.0 -Wl,-R/usr/pkg/lib -lpangocairo-1.0 -Wl,-R/usr/pkg/lib -lpango-1.0 -Wl,-R/usr/pkg/lib -lcairo -Wl,-R/usr/pkg/lib -lgdk_pixbuf-2.0 -Wl,-R/usr/pkg/lib -lgobject-2.0 -Wl,-R/usr/pkg/lib -lglib-2.0 
checking for pango >= 1.14.0... yes
checking _PANGOCHK_CFLAGS... -pthread -I/usr/pkg/include/pango-1.0 -I/usr/pkg/include/glib/glib-2.0 -I/usr/pkg/lib/glib-2.0/include -I/usr/pkg/include 
checking _PANGOCHK_LIBS... -L/usr/pkg/lib -Wl,-R/usr/pkg/lib -lpango-1.0 -Wl,-R/usr/pkg/lib -lgobject-2.0 -Wl,-R/usr/pkg/lib -lglib-2.0 
checking for pango >= 1.14.0 pangoft2 >= 1.14.0 pangocairo >= 1.14.0... yes
checking MOZ_PANGO_CFLAGS... -pthread -D_REENTRANT -I/usr/pkg/include/pango-1.0 -I/usr/pkg/include/harfbuzz -I/usr/pkg/include/pango-1.0 -I/usr/pkg/include/glib/glib-2.0 -I/usr/pkg/lib/glib-2.0/include -I/usr/pkg/include -I/usr/pkg/include/cairo -I/usr/pkg/include/pixman-1 -I/usr/pkg/include -I/usr/pkg/include/freetype2 -I/usr/pkg/include -I/usr/pkg/include/libpng16 -I/usr/pkg/include 
checking MOZ_PANGO_LIBS... -L/usr/pkg/lib -Wl,-R/usr/pkg/lib -lpangoft2-1.0 -Wl,-R/usr/pkg/lib -lfreetype -Wl,-R/usr/pkg/lib -lfontconfig -Wl,-R/usr/pkg/lib -lpangocairo-1.0 -Wl,-R/usr/pkg/lib -lpango-1.0 -Wl,-R/usr/pkg/lib -lgobject-2.0 -Wl,-R/usr/pkg/lib -lglib-2.0 -Wl,-R/usr/pkg/lib -lcairo 
checking for gtk+-2.0 >= 2.14... yes
checking _GTKCHECK_CFLAGS... -D_REENTRANT -pthread -I/usr/pkg/include/gtk-2.0 -I/usr/pkg/lib/gtk-2.0/include -I/usr/pkg/include/pango-1.0 -I/usr/pkg/include/atk-1.0 -I/usr/pkg/include/cairo -I/usr/pkg/include/pixman-1 -I/usr/pkg/include/libpng16 -I/usr/pkg/include -I/usr/pkg/include/gdk-pixbuf-2.0 -I/usr/pkg/include/libpng16 -I/usr/pkg/include/pango-1.0 -I/usr/pkg/include/harfbuzz -I/usr/pkg/include/pango-1.0 -I/usr/pkg/include/glib/glib-2.0 -I/usr/pkg/lib/glib-2.0/include -I/usr/pkg/include -I/usr/pkg/include/freetype2 -I/usr/pkg/include 
checking _GTKCHECK_LIBS... -L/usr/pkg/lib -Wl,-R/usr/pkg/lib -lgtk-x11-2.0 -Wl,-R/usr/pkg/lib -lgdk-x11-2.0 -Wl,-R/usr/pkg/lib -lpangocairo-1.0 -Wl,-R/usr/pkg/lib -latk-1.0 -Wl,-R/usr/pkg/lib -lcairo -Wl,-R/usr/pkg/lib -lgdk_pixbuf-2.0 -Wl,-R/usr/pkg/lib -lgio-2.0 -Wl,-R/usr/pkg/lib -lpangoft2-1.0 -Wl,-R/usr/pkg/lib -lpango-1.0 -Wl,-R/usr/pkg/lib -lgobject-2.0 -Wl,-R/usr/pkg/lib -lglib-2.0 -Wl,-R/usr/pkg/lib -lfreetype -Wl,-R/usr/pkg/lib -lfontconfig 
checking for gio-2.0 >= 2.20... yes
checking MOZ_GIO_CFLAGS... -pthread -I/usr/pkg/include/glib/glib-2.0 -I/usr/pkg/lib/glib-2.0/include -I/usr/pkg/include 
checking MOZ_GIO_LIBS... -L/usr/pkg/lib -Wl,-R/usr/pkg/lib -lgio-2.0 -Wl,-R/usr/pkg/lib -lgobject-2.0 -Wl,-R/usr/pkg/lib -lglib-2.0 
checking for gconf-2.0 >= 1.2.1 gobject-2.0 ... checking for libv4l2... Package libv4l2 was not found in the pkg-config search path. Perhaps you should add the directory containing `libv4l2.pc' to the PKG_CONFIG_PATH environment variable No package 'libv4l2' found
configure: error: Library requirements (libv4l2) not met; consider adjusting the PKG_CONFIG_PATH environment variable if your libraries are in a nonstandard prefix so pkg-config can find them.
configure: error: ./configure failed for mozilla
*** Error code 1

Stop.
bmake: stopped in /usr/pkgsrc/www/seamonkey
*** Error code 1

Stop.
bmake: stopped in /usr/pkgsrc/www/seamonkey
